""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.ubill.schemas import apis


class UBillClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UBillClient, self).__init__(config, transport, middleware, logger)

    def get_balance(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """GetBalance - 获取账户余额

        **Request**


        **Response**

        - **AccountInfo** (dict) - 见 **AccountInfo** 模型定义

        **Response Model**

        **AccountInfo**
        - **Amount** (str) - 账户余额
        - **AmountAvailable** (str) - 账户可用余额
        - **AmountCredit** (str) - 信用账户余额
        - **AmountFree** (str) - 赠送账户余额
        - **AmountFreeze** (str) - 冻结账户金额


        """
        # build request
        d = {}
        req and d.update(req)
        d = apis.GetBalanceRequestSchema().dumps(d)

        resp = self.invoke("GetBalance", d, **kwargs)
        return apis.GetBalanceResponseSchema().loads(resp)

    def get_bill_data_file_url(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetBillDataFileUrl - 生成账单数据文件下载的 url

        **Request**

        - **BillType** (int) - (Required) 账单类型，传 0 时获取账单总览报表，传 1 获取账单明细报表
        - **BillingCycle** (str) - (Required) 账期(字符串格式，YYYY-MM，例如2021-08).   若BillingCycle 和 BillPeriod同时存在，BillingCycle 优先
        - **BillPeriod** (int) - 此字段不推荐使用，建议使用BillingCycle.   若BillingCycle 和 BillPeriod同时存在，BillingCycle 优先
        - **PaidType** (int) - 获取账单总览报表时，账单的支付状态，传 0 时获取待支付账单，传 1 时获取已支付账单。获取账单明细报表时该参数无效
        - **RequireVersion** (str) - 如需求其他语言版本的账单则使用此参数。默认中文。如 RequireVersion = "EN"，则提供英文版本账单。
        - **Version** (str) - 文件版本，若为"v1"表示获取带有子用户信息的账单，可以为空

        **Response**

        - **FileUrl** (str) - 交易账单数据下载URL
        - **IsValid** (str) - 生成的 URL是否有效，即有对应数据文件

        """
        # build request
        d = {}
        req and d.update(req)
        d = apis.GetBillDataFileUrlRequestSchema().dumps(d)

        resp = self.invoke("GetBillDataFileUrl", d, **kwargs)
        return apis.GetBillDataFileUrlResponseSchema().loads(resp)

    def list_u_bill_detail(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ListUBillDetail - 获取某个账期内的所有消费。

        **Request**

        - **BillingCycle** (str) - (Required) 账期，YYYY-MM，比如2021-08，只支持2018-05之后的查询
        - **ChargeType** (str) - 计费方式 (筛选项, 默认全部)。枚举值：\\ > Dynamic:按时 \\ > Month:按月 \\ > Year:按年 \\ > Once:一次性按量 \\ > Used:按量 \\ > Post:后付费
        - **Limit** (int) - 每页数量，默认值25，最大值：100。
        - **Offset** (int) - 数据偏移量 (默认0)
        - **OrderType** (str) - 订单类型 (筛选项, 默认全部) 。枚举值：\\ > OT_BUY:新购 \\ > OT_RENEW:续费 \\ > OT_UPGRADE:升级 \\ > OT_REFUND:退费 \\ > OT_DOWNGRADE:降级 \\ > OT_SUSPEND:结算 \\ > OT_PAYMENT:删除资源回款 \\ > OT_POSTPAID_PAYMENT:后付费回款 \\ > OT_RECOVER:删除恢复 \\ > OT_POSTPAID_RENEW:过期续费回款
        - **PaidState** (int) - 支付状态 (筛选项, 1:仅显示未支付订单; 2:仅显示已支付订单; 0:两者都显示)
        - **ProjectName** (str) - 项目名称 (筛选项, 默认全部)
        - **ResourceIds** (list) - 资源ID(筛选项, 默认全部)	支持多筛选，多筛选请在请求参数中添加多个字段例ResourceIds.0: uhost-bzgf1gh5，ResourceIds.1: uhost-gu1xpspa，
        - **ResourceTypes** (list) - 产品类型 (筛选项, 默认全部),支持多筛选，多筛选请在请求参数中添加多个字段。枚举值：\\ > uhost:云主机 \\ > udisk:普通云硬盘 \\ > udb:云数据库 \\ > eip:弹性IP \\ > ufile:对象存储 \\ > fortress_host:堡垒机 \\ > ufs:文件存储 \\ > waf:WEB应用防火墙 \\ > ues:弹性搜索 \\ > udisk_ssd:SSD云硬盘 \\ > rssd:RSSD云硬盘
        - **ShowZero** (int) - 是否显示0元订单 (0 不显示, 1 显示, 默认0)
        - **UserEmail** (str) - 用户邮箱，可以根据用户邮箱来进行筛选

        **Response**

        - **Items** (list) - 见 **BillDetailItem** 模型定义
        - **TotalCount** (int) - 账单明细总长度

        **Response Model**

        **BillDetailItem**
        - **Admin** (int) - 是否为主账号。枚举值：\\ > 0:子账号 \\ > 1:主账号
        - **Amount** (str) - 订单总金额
        - **AmountCoupon** (str) - 代金券抵扣
        - **AmountFree** (str) - 赠送金额抵扣
        - **AmountReal** (str) - 现金账户支付
        - **AzGroupCName** (str) - 可用区
        - **ChargeType** (str) - 计费方式 (筛选项, 默认全部)。枚举值：\\ > Dynamic:按时 \\ > Month:按月 \\ > Year:按年 \\ > Once:一次性按量 \\ > Used:按量 \\ > Post:后付费
        - **CreateTime** (int) - 创建时间（时间戳）
        - **ItemDetails** (list) - 见 **ItemDetail** 模型定义
        - **OrderNo** (str) - 订单号
        - **OrderType** (str) - 订单类型 (筛选项, 默认全部) 。枚举值：\\ > OT_BUY:新购 \\ > OT_RENEW:续费 \\ > OT_UPGRADE:升级 \\ > OT_REFUND:退费 \\ > OT_DOWNGRADE:降级 \\ > OT_SUSPEND:结算 \\ > OT_PAYMENT:删除资源回款 \\ > OT_POSTPAID_PAYMENT:后付费回款 \\ > OT_RECOVER:删除恢复 \\ > OT_POSTPAID_RENEW:过期续费回款
        - **ProjectName** (str) - 项目名称
        - **ResourceExtendInfo** (list) - 见 **ResourceExtendInfo** 模型定义
        - **ResourceId** (str) - 资源ID
        - **ResourceType** (str) - 产品类型。枚举值：\\ > uhost:云主机 \\ > udisk:普通云硬盘 \\ > udb:云数据库 \\ > eip:弹性IP \\ > ufile:对象存储 \\ > fortress_host:堡垒机 \\ > ufs:文件存储 \\ > waf:WEB应用防火墙 \\ > ues:弹性搜索 \\ > udisk_ssd:SSD云硬盘 \\ > rssd:RSSD云硬盘
        - **ResourceTypeCode** (int) - 产品类型代码
        - **ShowHover** (int) - 订单支付状态。枚举值：\\> 0:未支付 \\ > 1:已支付
        - **StartTime** (int) - 开始时间（时间戳）
        - **UserDisplayName** (str) - 账户昵称
        - **UserEmail** (str) - 账户邮箱
        - **UserName** (str) - 账户名


        **ItemDetail**
        - **ProductName** (str) - 产品小类名称
        - **Value** (str) - 产品小类规格


        **ResourceExtendInfo**
        - **KeyId** (str) - 资源标识健
        - **Value** (str) - 资源标识值


        """
        # build request
        d = {}
        req and d.update(req)
        d = apis.ListUBillDetailRequestSchema().dumps(d)

        resp = self.invoke("ListUBillDetail", d, **kwargs)
        return apis.ListUBillDetailResponseSchema().loads(resp)

    def list_u_bill_overview(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ListUBillOverview - 账单总览。可按产品/项目/用户纬度获取某个账期内账单总览信息。

        **Request**

        - **BillingCycle** (str) - (Required) 账期，YYYY-MM格式，例如2022-02，只支持2018-05之后的查询
        - **Dimension** (str) - (Required) 账单维度, product 按产品聚合,project 按项目聚合，user 按子账号聚合
        - **HideUnpaid** (int) - 是否显示已入账账单, 1 已入账, 0 待入账 (默认0 )

        **Response**

        - **Items** (list) - 见 **BillOverviewItem** 模型定义
        - **TotalCount** (int) - 账单总览数据总数
        - **TotalPaidAmount** (str) - 已入账订单总额（已入账时显示）
        - **TotalPaidAmountReal** (str) - 现金账户扣款总额	（已入账时显示）
        - **TotalUnpaidAmount** (str) - 待入账订单总额（待入账时显示）

        **Response Model**

        **BillOverviewItem**
        - **Admin** (int) - 该账户是否为主账号，1 主账号，0 子账号（账单维度按子账号筛选时显示）
        - **Amount** (str) - 订单总金额
        - **AmountCoupon** (str) - 代金券抵扣（已入账时显示）
        - **AmountFree** (str) - 赠送金额抵扣（已入账时显示）
        - **AmountReal** (str) - 现金账户支付（已入账时显示）
        - **Dimension** (str) - 账单维度, product 按产品维度聚合,project 按项目维度聚合，user 按子账号维度聚合
        - **ProductCategory** (str) - 产品分类	（账单维度按产品筛选时显示）
        - **ProjectName** (str) - 项目名称（账单维度按项目筛选时显示）
        - **ResourceType** (str) - 产品类型	（账单维度按产品筛选时显示）
        - **ResourceTypeCode** (int) - 产品类型代码（账单维度按产品筛选时显示）
        - **UserDisplayName** (str) - 账户昵称（账单维度按子账号筛选时显示）
        - **UserEmail** (str) - 账户邮箱（账单维度按子账号筛选时显示）
        - **UserName** (str) - 账户名   （账单维度按子账号筛选时显示）


        """
        # build request
        d = {}
        req and d.update(req)
        d = apis.ListUBillOverviewRequestSchema().dumps(d)

        resp = self.invoke("ListUBillOverview", d, **kwargs)
        return apis.ListUBillOverviewResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uaccount.schemas import models

""" UAccount API Schema
"""


"""
API: AddMemberToProject

添加成员到项目
"""


class AddMemberToProjectRequestSchema(schema.RequestSchema):
    """AddMemberToProject - 添加成员到项目"""

    fields = {
        "CharacterId": fields.Str(required=True, dump_to="CharacterId"),
        "MemberEmail": fields.Str(required=True, dump_to="MemberEmail"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class AddMemberToProjectResponseSchema(schema.ResponseSchema):
    """AddMemberToProject - 添加成员到项目"""

    fields = {}


"""
API: CreateCharacter

创建角色
"""


class CreateCharacterRequestSchema(schema.RequestSchema):
    """CreateCharacter - 创建角色"""

    fields = {
        "Add": fields.List(fields.Str()),
        "CharacterDescription": fields.Str(
            required=False, dump_to="CharacterDescription"
        ),
        "CharacterName": fields.Str(required=True, dump_to="CharacterName"),
        "Del": fields.List(fields.Str()),
        "Get": fields.List(fields.Str()),
        "Mod": fields.List(fields.Str()),
    }


class CreateCharacterResponseSchema(schema.ResponseSchema):
    """CreateCharacter - 创建角色"""

    fields = {
        "CharacterId": fields.Str(required=True, load_from="CharacterId"),
    }


"""
API: CreateProject


"""


class CreateProjectRequestSchema(schema.RequestSchema):
    """CreateProject -"""

    fields = {
        "ProjectName": fields.Str(required=True, dump_to="ProjectName"),
    }


class CreateProjectResponseSchema(schema.ResponseSchema):
    """CreateProject -"""

    fields = {
        "ProjectId": fields.Str(required=True, load_from="ProjectId"),
    }


"""
API: DescribeCharacterList

获取角色列表
"""


class DescribeCharacterListRequestSchema(schema.RequestSchema):
    """DescribeCharacterList - 获取角色列表"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
    }


class DescribeCharacterListResponseSchema(schema.ResponseSchema):
    """DescribeCharacterList - 获取角色列表"""

    fields = {
        "CharacterSet": fields.List(
            models.CharacterSetSchema(), required=True, load_from="CharacterSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeMemberList

获取成员列表，限主账号使用。
"""


class DescribeMemberListRequestSchema(schema.RequestSchema):
    """DescribeMemberList - 获取成员列表，限主账号使用。"""

    fields = {
        "Limit": fields.Str(required=False, dump_to="Limit"),
        "Offset": fields.Str(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DescribeMemberListResponseSchema(schema.ResponseSchema):
    """DescribeMemberList - 获取成员列表，限主账号使用。"""

    fields = {
        "MemberSet": fields.List(
            models.MemberInfoSchema(), required=True, load_from="MemberSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: FreezeMember

冻结成员
"""


class FreezeMemberRequestSchema(schema.RequestSchema):
    """FreezeMember - 冻结成员"""

    fields = {
        "MemberEmail": fields.Str(required=True, dump_to="MemberEmail"),
    }


class FreezeMemberResponseSchema(schema.ResponseSchema):
    """FreezeMember - 冻结成员"""

    fields = {}


"""
API: GetNetworkMask

查询登录与API调用的网络掩码
"""


class GetNetworkMaskRequestSchema(schema.RequestSchema):
    """GetNetworkMask - 查询登录与API调用的网络掩码"""

    fields = {}


class GetNetworkMaskResponseSchema(schema.ResponseSchema):
    """GetNetworkMask - 查询登录与API调用的网络掩码"""

    fields = {
        "Data": models.NetworkMaskSchema(),
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: GetProjectList

获取项目列表
"""


class GetProjectListRequestSchema(schema.RequestSchema):
    """GetProjectList - 获取项目列表"""

    fields = {
        "IsFinance": fields.Str(required=False, dump_to="IsFinance"),
    }


class GetProjectListResponseSchema(schema.ResponseSchema):
    """GetProjectList - 获取项目列表"""

    fields = {
        "ProjectCount": fields.Int(required=True, load_from="ProjectCount"),
        "ProjectSet": fields.List(
            models.ProjectListInfoSchema(),
            required=True,
            load_from="ProjectSet",
        ),
    }


"""
API: GetRegion

获取用户在各数据中心的权限等信息
"""


class GetRegionRequestSchema(schema.RequestSchema):
    """GetRegion - 获取用户在各数据中心的权限等信息"""

    fields = {}


class GetRegionResponseSchema(schema.ResponseSchema):
    """GetRegion - 获取用户在各数据中心的权限等信息"""

    fields = {
        "Regions": fields.List(
            models.RegionInfoSchema(), required=False, load_from="Regions"
        ),
    }


"""
API: GetUserInfo


"""


class GetUserInfoRequestSchema(schema.RequestSchema):
    """GetUserInfo -"""

    fields = {}


class GetUserInfoResponseSchema(schema.ResponseSchema):
    """GetUserInfo -"""

    fields = {
        "DataSet": fields.List(
            models.UserInfoSchema(), required=True, load_from="DataSet"
        ),
    }


"""
API: InviteSubaccount

邀请子帐号成员
"""


class InviteSubaccountRequestSchema(schema.RequestSchema):
    """InviteSubaccount - 邀请子帐号成员"""

    fields = {
        "IsFinance": fields.Str(required=True, dump_to="IsFinance"),
        "UserEmail": fields.Str(required=True, dump_to="UserEmail"),
        "UserName": fields.Str(required=True, dump_to="UserName"),
        "UserPhone": fields.Str(required=True, dump_to="UserPhone"),
    }


class InviteSubaccountResponseSchema(schema.ResponseSchema):
    """InviteSubaccount - 邀请子帐号成员"""

    fields = {}


"""
API: ModifyCharacter

修改角色
"""


class ModifyCharacterRequestSchema(schema.RequestSchema):
    """ModifyCharacter - 修改角色"""

    fields = {
        "Add": fields.List(fields.Str()),
        "CharacterDescription": fields.Str(
            required=False, dump_to="CharacterDescription"
        ),
        "CharacterId": fields.Str(required=True, dump_to="CharacterId"),
        "CharacterName": fields.Str(required=False, dump_to="CharacterName"),
        "Del": fields.List(fields.Str()),
        "Get": fields.List(fields.Str()),
        "Mod": fields.List(fields.Str()),
    }


class ModifyCharacterResponseSchema(schema.ResponseSchema):
    """ModifyCharacter - 修改角色"""

    fields = {}


"""
API: ModifyProject


"""


class ModifyProjectRequestSchema(schema.RequestSchema):
    """ModifyProject -"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "ProjectName": fields.Str(required=True, dump_to="ProjectName"),
    }


class ModifyProjectResponseSchema(schema.ResponseSchema):
    """ModifyProject -"""

    fields = {}


"""
API: RemoveMemberFromProject

从项目中移除成员
"""


class RemoveMemberFromProjectRequestSchema(schema.RequestSchema):
    """RemoveMemberFromProject - 从项目中移除成员"""

    fields = {
        "MemberEmail": fields.Str(required=True, dump_to="MemberEmail"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
    }


class RemoveMemberFromProjectResponseSchema(schema.ResponseSchema):
    """RemoveMemberFromProject - 从项目中移除成员"""

    fields = {}


"""
API: SetNetworkMask

设置登录与API调用的网络掩码
"""


class SetNetworkMaskRequestSchema(schema.RequestSchema):
    """SetNetworkMask - 设置登录与API调用的网络掩码"""

    fields = {
        "APINetworkMask": fields.Str(required=False, dump_to="APINetworkMask"),
        "Code": fields.Str(required=True, dump_to="Code"),
        "LoginNetworkMask": fields.Str(
            required=False, dump_to="LoginNetworkMask"
        ),
    }


class SetNetworkMaskResponseSchema(schema.ResponseSchema):
    """SetNetworkMask - 设置登录与API调用的网络掩码"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: TerminateCharacter

删除用户角色管理列表中的指定角色
"""


class TerminateCharacterRequestSchema(schema.RequestSchema):
    """TerminateCharacter - 删除用户角色管理列表中的指定角色"""

    fields = {
        "CharacterId": fields.Str(required=True, dump_to="CharacterId"),
    }


class TerminateCharacterResponseSchema(schema.ResponseSchema):
    """TerminateCharacter - 删除用户角色管理列表中的指定角色"""

    fields = {}


"""
API: TerminateMember

删除管理员人员管理页面的指定子账号
"""


class TerminateMemberRequestSchema(schema.RequestSchema):
    """TerminateMember - 删除管理员人员管理页面的指定子账号"""

    fields = {
        "MemberEmail": fields.Str(required=True, dump_to="MemberEmail"),
    }


class TerminateMemberResponseSchema(schema.ResponseSchema):
    """TerminateMember - 删除管理员人员管理页面的指定子账号"""

    fields = {}


"""
API: TerminateProject

删除项目
"""


class TerminateProjectRequestSchema(schema.RequestSchema):
    """TerminateProject - 删除项目"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
    }


class TerminateProjectResponseSchema(schema.ResponseSchema):
    """TerminateProject - 删除项目"""

    fields = {}



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.isms.schemas import models

""" ISMS API Schema
"""


"""
API: CreateISMSSignature

调用接口CreateISMSSignature申请视频短信签名
"""


class CreateISMSSignatureRequestSchema(schema.RequestSchema):
    """CreateISMSSignature - 调用接口CreateISMSSignature申请视频短信签名"""

    fields = {
        "CertificateType": fields.Int(required=True, dump_to="CertificateType"),
        "Description": fields.Str(required=True, dump_to="Description"),
        "File": fields.Str(required=True, dump_to="File"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "ProxyFile": fields.Str(required=False, dump_to="ProxyFile"),
        "SigContent": fields.Str(required=True, dump_to="SigContent"),
        "SigPurpose": fields.Int(required=True, dump_to="SigPurpose"),
        "SigType": fields.Int(required=True, dump_to="SigType"),
    }


class CreateISMSSignatureResponseSchema(schema.ResponseSchema):
    """CreateISMSSignature - 调用接口CreateISMSSignature申请视频短信签名"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "SigId": fields.Str(required=False, load_from="SigId"),
    }


"""
API: CreateISMSTemplate

申请视频短信模板
"""


class CreateISMSTemplateRequestSchema(schema.RequestSchema):
    """CreateISMSTemplate - 申请视频短信模板"""

    fields = {
        "Content": fields.Str(required=True, dump_to="Content"),
        "MsgSignature": fields.Str(required=True, dump_to="MsgSignature"),
        "MsgTitle": fields.Str(required=True, dump_to="MsgTitle"),
        "NetworkOperator": fields.Str(
            required=False, dump_to="NetworkOperator"
        ),  # Deprecated, will be removed at 1.0
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Purpose": fields.Int(
            required=False, dump_to="Purpose"
        ),  # Deprecated, will be removed at 1.0
        "Region": fields.Str(required=False, dump_to="Region"),
        "Remark": fields.Str(required=True, dump_to="Remark"),
        "TemplateName": fields.Str(required=True, dump_to="TemplateName"),
        "UnsubscribeInfo": fields.Str(required=True, dump_to="UnsubscribeInfo"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class CreateISMSTemplateResponseSchema(schema.ResponseSchema):
    """CreateISMSTemplate - 申请视频短信模板"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ReqUuid": fields.Str(required=True, load_from="ReqUuid"),
        "TemplateId": fields.Str(required=True, load_from="TemplateId"),
    }


"""
API: DeleteISMSSignature

调用接口DeleteISMSSignature删除视频短信签名
"""


class DeleteISMSSignatureRequestSchema(schema.RequestSchema):
    """DeleteISMSSignature - 调用接口DeleteISMSSignature删除视频短信签名"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "SigIds": fields.List(fields.Str()),
    }


class DeleteISMSSignatureResponseSchema(schema.ResponseSchema):
    """DeleteISMSSignature - 调用接口DeleteISMSSignature删除视频短信签名"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: DeleteISMSTemplate

调用接口DeleteISMSTemplate删除视频短信模板
"""


class DeleteISMSTemplateRequestSchema(schema.RequestSchema):
    """DeleteISMSTemplate - 调用接口DeleteISMSTemplate删除视频短信模板"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "TemplateIds": fields.List(fields.Str()),
    }


class DeleteISMSTemplateResponseSchema(schema.ResponseSchema):
    """DeleteISMSTemplate - 调用接口DeleteISMSTemplate删除视频短信模板"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: GetISMSSendReceipt

获取视频短信发送记录的状态回执
"""


class GetISMSSendReceiptRequestSchema(schema.RequestSchema):
    """GetISMSSendReceipt - 获取视频短信发送记录的状态回执"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "TaskIdSet": fields.List(fields.Str()),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class GetISMSSendReceiptResponseSchema(schema.ResponseSchema):
    """GetISMSSendReceipt - 获取视频短信发送记录的状态回执"""

    fields = {
        "Data": fields.List(
            models.ReceiptPerTaskSchema(), required=False, load_from="Data"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "ReqUuid": fields.Str(required=True, load_from="ReqUuid"),
    }


"""
API: QueryISMSSignature

调用接口QueryISMSSignature查询视频短信签名申请状态
"""


class QueryISMSSignatureRequestSchema(schema.RequestSchema):
    """QueryISMSSignature - 调用接口QueryISMSSignature查询视频短信签名申请状态"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SigContent": fields.Str(required=False, dump_to="SigContent"),
        "SigId": fields.Str(required=True, dump_to="SigId"),
    }


class QueryISMSSignatureResponseSchema(schema.ResponseSchema):
    """QueryISMSSignature - 调用接口QueryISMSSignature查询视频短信签名申请状态"""

    fields = {
        "Data": models.OutSignatureSchema(),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: QueryISMSTemplate

查询模板状态信息
"""


class QueryISMSTemplateRequestSchema(schema.RequestSchema):
    """QueryISMSTemplate - 查询模板状态信息"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "TemplateId": fields.Str(required=True, dump_to="TemplateId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class QueryISMSTemplateResponseSchema(schema.ResponseSchema):
    """QueryISMSTemplate - 查询模板状态信息"""

    fields = {
        "Data": models.OutTemplateSchema(),
        "Message": fields.Str(required=True, load_from="Message"),
        "ReqUuid": fields.Str(required=False, load_from="ReqUuid"),
    }


"""
API: SendISMSMessage

发送视频短信
"""


class SendISMSMessageRequestSchema(schema.RequestSchema):
    """SendISMSMessage - 发送视频短信"""

    fields = {
        "PhoneSet": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "TemplateId": fields.Str(required=True, dump_to="TemplateId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class SendISMSMessageResponseSchema(schema.ResponseSchema):
    """SendISMSMessage - 发送视频短信"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ReqUuid": fields.Str(required=True, load_from="ReqUuid"),
        "TaskId": fields.Str(required=True, load_from="TaskId"),
    }


"""
API: UpdateISMSSignature

调用接口UpdateISMSSignature修改未通过审核的视频短信签名，并重新提交审核
"""


class UpdateISMSSignatureRequestSchema(schema.RequestSchema):
    """UpdateISMSSignature - 调用接口UpdateISMSSignature修改未通过审核的视频短信签名，并重新提交审核"""

    fields = {
        "CertificateType": fields.Int(
            required=False, dump_to="CertificateType"
        ),
        "Document": fields.Str(required=False, dump_to="Document"),
        "File": fields.Str(required=False, dump_to="File"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "ProxyDoc": fields.Str(required=False, dump_to="ProxyDoc"),
        "ProxyFile": fields.Str(required=False, dump_to="ProxyFile"),
        "SigContent": fields.Str(required=True, dump_to="SigContent"),
        "SigId": fields.Str(required=True, dump_to="SigId"),
        "SigPurpose": fields.Int(required=True, dump_to="SigPurpose"),
        "SigType": fields.Int(required=True, dump_to="SigType"),
    }


class UpdateISMSSignatureResponseSchema(schema.ResponseSchema):
    """UpdateISMSSignature - 调用接口UpdateISMSSignature修改未通过审核的视频短信签名，并重新提交审核"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class UnetEIPAddrSetSchema(schema.ResponseSchema):
    """UnetEIPAddrSet - DescribeEIP"""

    fields = {
        "IP": fields.Str(required=False, load_from="IP"),
        "OperatorName": fields.Str(required=False, load_from="OperatorName"),
    }


class UnetAllocateEIPSetSchema(schema.ResponseSchema):
    """UnetAllocateEIPSet - AllocateEIP"""

    fields = {
        "EIPAddr": fields.List(UnetEIPAddrSetSchema()),
        "EIPId": fields.Str(required=False, load_from="EIPId"),
    }


class EIPAddrSetSchema(schema.ResponseSchema):
    """EIPAddrSet - DescribeBandwidthPackage"""

    fields = {
        "IP": fields.Str(required=False, load_from="IP"),
        "OperatorName": fields.Str(required=False, load_from="OperatorName"),
    }


class UnetBandwidthPackageSetSchema(schema.ResponseSchema):
    """UnetBandwidthPackageSet - DescribeBandwidthPackage"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "BandwidthPackageId": fields.Str(
            required=False, load_from="BandwidthPackageId"
        ),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DisableTime": fields.Int(required=False, load_from="DisableTime"),
        "EIPAddr": fields.List(EIPAddrSetSchema()),
        "EIPId": fields.Str(required=False, load_from="EIPId"),
        "EnableTime": fields.Int(required=False, load_from="EnableTime"),
    }


class UnetBandwidthUsageEIPSetSchema(schema.ResponseSchema):
    """UnetBandwidthUsageEIPSet - DescribeBandwidthUsage"""

    fields = {
        "CurBandwidth": fields.Float(required=False, load_from="CurBandwidth"),
        "EIPId": fields.Str(required=False, load_from="EIPId"),
    }


class ShareBandwidthSetSchema(schema.ResponseSchema):
    """ShareBandwidthSet - DescribeEIP"""

    fields = {
        "ShareBandwidth": fields.Int(
            required=False, load_from="ShareBandwidth"
        ),
        "ShareBandwidthId": fields.Str(
            required=False, load_from="ShareBandwidthId"
        ),
        "ShareBandwidthName": fields.Str(
            required=False, load_from="ShareBandwidthName"
        ),
    }


class UnetEIPResourceSetSchema(schema.ResponseSchema):
    """UnetEIPResourceSet - DescribeEIP"""

    fields = {
        "EIPId": fields.Str(required=False, load_from="EIPId"),
        "ResourceID": fields.Str(required=False, load_from="ResourceID"),
        "ResourceId": fields.Str(
            required=False, load_from="ResourceId"
        ),  # Deprecated, will be removed at 1.0
        "ResourceName": fields.Str(required=False, load_from="ResourceName"),
        "ResourceType": fields.Str(required=False, load_from="ResourceType"),
        "SubResourceId": fields.Str(required=False, load_from="SubResourceId"),
        "SubResourceName": fields.Str(
            required=False, load_from="SubResourceName"
        ),
        "SubResourceType": fields.Str(
            required=False, load_from="SubResourceType"
        ),
    }


class UnetEIPSetSchema(schema.ResponseSchema):
    """UnetEIPSet - DescribeEIP"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "BandwidthType": fields.Int(required=False, load_from="BandwidthType"),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "EIPAddr": fields.List(UnetEIPAddrSetSchema()),
        "EIPId": fields.Str(required=False, load_from="EIPId"),
        "Expire": fields.Bool(required=False, load_from="Expire"),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "Name": fields.Str(required=False, load_from="Name"),
        "PayMode": fields.Str(required=False, load_from="PayMode"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "Resource": UnetEIPResourceSetSchema(),
        "ShareBandwidthSet": ShareBandwidthSetSchema(),
        "Status": fields.Str(required=False, load_from="Status"),
        "Tag": fields.Str(required=False, load_from="Tag"),
        "Weight": fields.Int(required=False, load_from="Weight"),
    }


class FirewallRuleSetSchema(schema.ResponseSchema):
    """FirewallRuleSet - DescribeFirewall"""

    fields = {
        "DstPort": fields.Str(required=False, load_from="DstPort"),
        "Priority": fields.Str(required=False, load_from="Priority"),
        "ProtocolType": fields.Str(required=False, load_from="ProtocolType"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "RuleAction": fields.Str(required=False, load_from="RuleAction"),
        "SrcIP": fields.Str(required=False, load_from="SrcIP"),
    }


class FirewallDataSetSchema(schema.ResponseSchema):
    """FirewallDataSet - DescribeFirewall"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "FWId": fields.Str(required=True, load_from="FWId"),
        "GroupId": fields.Str(required=True, load_from="GroupId"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "ResourceCount": fields.Int(required=False, load_from="ResourceCount"),
        "Rule": fields.List(FirewallRuleSetSchema()),
        "Tag": fields.Str(required=False, load_from="Tag"),
        "Type": fields.Str(required=False, load_from="Type"),
    }


class ResourceSetSchema(schema.ResponseSchema):
    """ResourceSet - 资源信息"""

    fields = {
        "Name": fields.Str(required=False, load_from="Name"),
        "PrivateIP": fields.Str(required=False, load_from="PrivateIP"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "ResourceID": fields.Str(required=False, load_from="ResourceID"),
        "ResourceType": fields.Str(required=False, load_from="ResourceType"),
        "Status": fields.Int(required=False, load_from="Status"),
        "SubResourceId": fields.Str(required=True, load_from="SubResourceId"),
        "SubResourceName": fields.Str(
            required=True, load_from="SubResourceName"
        ),
        "SubResourceType": fields.Str(
            required=True, load_from="SubResourceType"
        ),
        "Tag": fields.Str(required=False, load_from="Tag"),
        "Zone": fields.Int(required=False, load_from="Zone"),
    }


class EIPSetDataSchema(schema.ResponseSchema):
    """EIPSetData - describeShareBandwidth"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "EIPAddr": fields.List(EIPAddrSetSchema()),
        "EIPId": fields.Str(required=False, load_from="EIPId"),
    }


class UnetShareBandwidthSetSchema(schema.ResponseSchema):
    """UnetShareBandwidthSet - DescribeShareBandwidth"""

    fields = {
        "BandwidthGuarantee": fields.Int(
            required=False, load_from="BandwidthGuarantee"
        ),  # Deprecated, will be removed at 1.0
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "EIPSet": fields.List(EIPSetDataSchema()),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "IPVersion": fields.Str(required=True, load_from="IPVersion"),
        "Name": fields.Str(required=False, load_from="Name"),
        "PostPayStartTime": fields.Int(
            required=False, load_from="PostPayStartTime"
        ),  # Deprecated, will be removed at 1.0
        "ShareBandwidth": fields.Int(
            required=False, load_from="ShareBandwidth"
        ),
        "ShareBandwidthId": fields.Str(
            required=False, load_from="ShareBandwidthId"
        ),
    }


class EIPPayModeSetSchema(schema.ResponseSchema):
    """EIPPayModeSet - GetEIPPayModeEIP"""

    fields = {
        "EIPId": fields.Str(required=False, load_from="EIPId"),
        "EIPPayMode": fields.Str(required=False, load_from="EIPPayMode"),
    }


class EIPPriceDetailSetSchema(schema.ResponseSchema):
    """EIPPriceDetailSet - GetEIPPrice"""

    fields = {
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "OriginalPrice": fields.Float(
            required=False, load_from="OriginalPrice"
        ),
        "Price": fields.Float(required=False, load_from="Price"),
        "PurchaseValue": fields.Int(required=False, load_from="PurchaseValue"),
    }


class ThroughputDailyBillingInfoSchema(schema.ResponseSchema):
    """ThroughputDailyBillingInfo - 流量计费EIP计费信息"""

    fields = {
        "BillingState": fields.Str(required=False, load_from="BillingState"),
        "EndTime": fields.Int(required=False, load_from="EndTime"),
        "QuantityOut": fields.Int(required=False, load_from="QuantityOut"),
        "StartTime": fields.Int(required=False, load_from="StartTime"),
    }



import base64
import typing
from collections.abc import Iterable

from ucloud.core.typesystem import abstract
from ucloud.core.exc import ValidationException
from ucloud.core.utils.compat import str


class List(abstract.Field):
    """array param is the custom field to parse custom param such as:

    - IP.N
    - UDisk.N.Size
    - NetInterface.N.EIP.Bandwidth
    """

    def __init__(
        self,
        item: typing.Union[abstract.Field, abstract.Schema],
        default=list,
        **kwargs
    ):
        super(List, self).__init__(default=default, **kwargs)
        self.item = item

    def dumps(self, value, name=None, **kwargs):
        if not isinstance(value, Iterable):
            raise ValidationException(
                "invalid field {}, expect list, got {}".format(
                    name, type(value)
                )
            )

        errors = []
        values = []
        for each in value:
            try:
                v = self.item.dumps(each)
            except ValidationException as e:
                errors.extend(e.errors)
            else:
                values.append(v)

        if len(errors) > 0:
            raise ValidationException(errors)

        return values

    def loads(self, value, name=None, **kwargs):
        if not isinstance(value, Iterable):
            raise ValidationException(
                "invalid field {}, expect list, got {}".format(
                    name, type(value)
                )
            )

        errors = []
        values = []
        for each in value:
            try:
                v = self.item.loads(each)
            except ValidationException as e:
                errors.extend(e.errors)
            else:
                values.append(v)

        if len(errors) > 0:
            raise ValidationException(errors)

        return values


class Str(abstract.Field):
    def dumps(self, value, name=None, **kwargs):
        return self._convert(value, name)

    def loads(self, value, name=None, **kwargs):
        return self._convert(value, name)

    def _convert(self, value, name=None):
        if self.strict and not isinstance(value, str):
            self.fail(name, "str", type(value))

        return str(value)


class Base64(Str):
    def dumps(self, value, name=None, **kwargs):
        s = super(Base64, self).dumps(value, name)
        return base64.b64encode(s.encode()).decode()

    def loads(self, value, name=None, **kwargs):
        s = super(Base64, self).loads(value, name)
        return base64.b64decode(s.encode()).decode()


class Int(abstract.Field):
    def dumps(self, value, name=None, **kwargs):
        return self._convert(value, name)

    def loads(self, value, name=None, **kwargs):
        return self._convert(value, name)

    def _convert(self, value, name=None):
        if self.strict and not isinstance(value, int):
            self.fail(name, "int", type(value))

        try:
            return int(value)
        except ValueError:
            self.fail(name, "int", type(value))


class Float(abstract.Field):
    def dumps(self, value, name=None, **kwargs):
        return self._convert(value, name)

    def loads(self, value, name=None, **kwargs):
        return self._convert(value, name)

    def _convert(self, value, name=None):
        if self.strict and not isinstance(value, float):
            self.fail(name, "float", type(value))

        try:
            return float(value)
        except ValueError:
            self.fail(name, "float", type(value))


class Bool(abstract.Field):
    def dumps(self, value, name=None, **kwargs):
        return self._convert(value, name)

    def loads(self, value, name=None, **kwargs):
        return self._convert(value, name)

    def _convert(self, value, name=None):
        if self.strict and not isinstance(value, bool):
            self.fail(name, "bool", type(value))

        if value == "true" or value is True:
            return True

        if value == "false" or value is False:
            return False

        self.fail(name, "bool", type(value))



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.udpn.schemas import apis


class UDPNClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UDPNClient, self).__init__(config, transport, middleware, logger)

    def allocate_udpn(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """AllocateUDPN - 分配一条 UDPN 专线

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Bandwidth** (int) - (Required) 带宽
        - **Peer1** (str) - (Required) 专线可用区1，支持地域：北京二：cn-bj2, 上海二：cn-sh2, 广东：cn-gd, 亚太： hk, 上海一：cn-sh1, 法兰克福：ge-fra, 新加坡：sg,  洛杉矶：us-ca， 华盛顿：us-ws， 东京：jpn-tky
        - **Peer2** (str) - (Required) 专线可用区2，支持地域：北京二：cn-bj2, 上海二：cn-sh2, 广东：cn-gd, 亚太： hk, 上海一：cn-sh1, 法兰克福：ge-fra, 新加坡：sg,  洛杉矶：us-ca， 华盛顿：us-ws， 东京：jpn-tky
        - **ChargeType** (str) - 计费类型，枚举值为： Year，按年付费； Month，按月付费； Dynamic，按需付费
        - **CouponId** (str) - 代金劵
        - **PayMode** (str) - 计费模式. 枚举值："Traffic", 流量计费模式; 否则 带宽计费模式；
        - **Quantity** (int) - 计费时长，默认 1

        **Response**

        - **Action** (str) - 操作名称
        - **RetCode** (int) - 返回码
        - **UDPNId** (str) - 资源名称

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.AllocateUDPNRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("AllocateUDPN", d, **kwargs)
        return apis.AllocateUDPNResponseSchema().loads(resp)

    def describe_udpn(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUDPN - 描述 UDPN

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Limit** (int) - 返回数据长度，默认为 20
        - **Offset** (int) - 列表起始位置偏移量，默认为 0
        - **UDPNId** (str) - 申请到的 UDPN 资源 ID。若为空，则查询该用户在机房所有的专线信息。非默认项目资源，需填写ProjectId

        **Response**

        - **DataSet** (list) - 见 **UDPNData** 模型定义
        - **TotalCount** (int) - 查询到的总数量

        **Response Model**

        **UDPNData**
        - **Bandwidth** (int) - 带宽
        - **ChargeType** (str) - 计费类型
        - **CreateTime** (int) - unix 时间戳 创建时间
        - **ExpireTime** (int) - unix 时间戳 到期时间
        - **Peer1** (str) - 可用区域 1
        - **Peer2** (str) - 可用区域 2
        - **UDPNId** (str) - UDPN 资源短 ID


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUDPNRequestSchema().dumps(d)

        resp = self.invoke("DescribeUDPN", d, **kwargs)
        return apis.DescribeUDPNResponseSchema().loads(resp)

    def get_udpn_line_list(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUDPNLineList - 获取当前支持的专线线路列表

        **Request**

        - **ProjectId** (str) - (Config)
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **DataSet** (list) - 见 **UDPNLineSet** 模型定义
        - **TotalCount** (int) - DataSet中的元素个数

        **Response Model**

        **UDPNLineSet**
        - **BandwidthUpperLimit** (int) - 线路带宽上限,单位 M
        - **LocalRegion** (str) - 支持UDPN的地域之一，北京二：cn-bj2, 上海二：cn-sh2, 广东：cn-gd, 亚太： hk, 上海一：cn-sh1, 法兰克福：ge-fra, 新加坡：sg, 华盛顿：us-ws, 洛杉矶：us-la， 东京：jpn-tky
        - **RemoteRegion** (str) - 支持UDPN的地域之一，北京二：cn-bj2, 上海二：cn-sh2, 广东：cn-gd, 亚太： hk, 上海一：cn-sh1, 法兰克福：ge-fra, 新加坡：sg, 华盛顿：us-ws, 洛杉矶：us-la， 东京：jpn-tky


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetUDPNLineListRequestSchema().dumps(d)

        resp = self.invoke("GetUDPNLineList", d, **kwargs)
        return apis.GetUDPNLineListResponseSchema().loads(resp)

    def get_udpn_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUDPNPrice - 获取 UDPN 价格

        **Request**

        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **Bandwidth** (int) - (Required) 带宽信息
        - **Peer1** (str) - (Required) 专线可用区1，支持地域：北京二：cn-bj2, 上海二：cn-sh2, 广东：cn-gd, 亚太： hk, 上海一：cn-sh1, 法兰克福：ge-fra, 新加坡：sg, 洛杉矶：us-la， 华盛顿：us-ws， 东京：jpn-tky
        - **Peer2** (str) - (Required) 专线可用区2，支持地域：北京二：cn-bj2, 上海二：cn-sh2, 广东：cn-gd, 亚太： hk, 上海一：cn-sh1, 法兰克福：ge-fra, 新加坡：sg, 洛杉矶：us-la， 华盛顿：us-ws， 东京：jpn-tky
        - **ChargeType** (str) - 计费类型
        - **PayMode** (str) - PayMode，枚举值，Bandwidth：带宽；Traffic：流量  默认不填写：带宽
        - **Quantity** (int) - 购买时长

        **Response**

        - **Price** (float) - 专线价格
        - **PurchaseValue** (int) - 资源有效期 unix 时间戳

        """
        # build request
        d = {
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetUDPNPriceRequestSchema().dumps(d)

        resp = self.invoke("GetUDPNPrice", d, **kwargs)
        return apis.GetUDPNPriceResponseSchema().loads(resp)

    def get_udpn_upgrade_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUDPNUpgradePrice - 获取专线升级价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **Bandwidth** (int) - (Required) 带宽
        - **UDPNId** (str) - (Required) 专线带宽资源 Id

        **Response**

        - **Price** (float) - 升级后的价格

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetUDPNUpgradePriceRequestSchema().dumps(d)

        resp = self.invoke("GetUDPNUpgradePrice", d, **kwargs)
        return apis.GetUDPNUpgradePriceResponseSchema().loads(resp)

    def modify_udpn_bandwidth(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUDPNBandwidth - 修改带宽值

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config)
        - **Bandwidth** (int) - (Required) 调整后专线带宽, 单位为Mbps，取值范围为大于等于2且小于等于1000([2-1000])的整数
        - **UDPNId** (str) - (Required) UDPN Id
        - **CouponId** (str) - 代金劵 ID

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ModifyUDPNBandwidthRequestSchema().dumps(d)

        resp = self.invoke("ModifyUDPNBandwidth", d, **kwargs)
        return apis.ModifyUDPNBandwidthResponseSchema().loads(resp)

    def release_udpn(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """ReleaseUDPN - 释放 UDPN

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **UDPNId** (str) - (Required) UDPN 资源 Id

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ReleaseUDPNRequestSchema().dumps(d)

        resp = self.invoke("ReleaseUDPN", d, **kwargs)
        return apis.ReleaseUDPNResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.uvms.schemas import apis


class UVMSClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UVMSClient, self).__init__(config, transport, middleware, logger)

    def send_uvms_message(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """SendUVMSMessage - 向指定号码拨打电话

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config)
        - **CalledNumber** (str) - (Required) 被叫号码，采用 E.164 标准，格式为+[国家代码][用户号码]。例如：+8613512345678， 其中前面有一个+号 ，86为国家码，13512345678为手机号
        - **TemplateId** (str) - (Required) 模板 ID，在控制台审核通过的模板 ID。
        - **Zone** (str) - (Required)
        - **DispatchRule** (int) - 调度规则，0-默认（归属地优先），1-随机。当不指定外显号码（主叫号码为空）时生效。如不填写，默认为归属地优先。
        - **FromNumber** (str) - 主叫号码，号码随机时不填。专属号码时传入已购买的号码，仅支持一个号码，在控制台查看已购买的号码。
        - **GroupType** (int) - 号码组类型，1-随机组，2-专属组。如不填写则根据主叫号码判断，若主叫号码为空，则为随机组，若不为空，则为专属组。
        - **TemplateParams** (list) - 模板可变参数，以数组的方式填写，举例，TemplateParams.0，TemplateParams.1，... 若模板中无可变参数，则该项可不填写；若模板中有可变参数，则该项为必填项，参数个数需与变量个数保持一致，否则无法发送；
        - **UserId** (str) - 自定义的业务标识ID，字符串（ 长度不能超过32 位），不支持 单引号、表情包符号等特殊字符

        **Response**

        - **Message** (str) - 状态码的描述
        - **ReqUuid** (str) - 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 ReqUuid。
        - **SessionNo** (str) - 本次提交发送语音的唯一ID，可根据该值查询本次发送详情
        - **UserId** (str) - 本次提交的自定义业务标识ID，仅当发送时传入有效的UserId，才返回该字段。

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.SendUVMSMessageRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("SendUVMSMessage", d, **kwargs)
        return apis.SendUVMSMessageResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.tidb.schemas import apis


class TiDBClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(TiDBClient, self).__init__(config, transport, middleware, logger)

    def create_ti_db_service(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateTiDBService - 创建TiDB服务

        **Request**

        - **ProjectId** (str) - (Config) 项目 ID
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Name** (str) - (Required) 服务名称， 长度不超过64
        - **Password** (str) - (Required) 服务root账号的密码， 长度不超过32
        - **SubnetId** (str) - (Required) 子网 ID
        - **VPCId** (str) - (Required) VPC ID
        - **DTType** (str) - 容灾类型：10:同可用区，20:跨可用区，默认是同可用区
        - **Ip** (str) - ipv4
        - **Port** (str) - 端口
        - **TikvMemoryHardTh** (str) - 实例类型:   0: 旗舰版，30: 体验版，60: 轻量版

        **Response**

        - **Data** (dict) - 见 **ServiceID** 模型定义
        - **Message** (str) - 返回信息
        - **ServiceId** (str) - 服务ID

        **Response Model**

        **ServiceID**
        - **Id** (str) - 服务ID


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateTiDBServiceRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateTiDBService", d, **kwargs)
        return apis.CreateTiDBServiceResponseSchema().loads(resp)

    def delete_ti_db_service(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteTiDBService - 删除一个服务

        **Request**

        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Id** (str) - (Required) 资源ID

        **Response**

        - **Message** (str) - 返回信息
        - **ServiceId** (str) - ServiceId

        """
        # build request
        d = {
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteTiDBServiceRequestSchema().dumps(d)

        resp = self.invoke("DeleteTiDBService", d, **kwargs)
        return apis.DeleteTiDBServiceResponseSchema().loads(resp)

    def set_ti_db_config(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """SetTiDBConfig - 设置TiDB服务实例参数

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Id** (str) - (Required) 资源Id
        - **Configs** (list) - 见 **SetTiDBConfigParamConfigs** 模型定义

        **Response**

        - **ServiceId** (str) - ServiceId

        **Request Model**

        **SetTiDBConfigParamConfigs**
        - **Name** (str) - 修改的参数名: proxysql_mysql-max_connections:类型：string, 描述:  所有用户总共的最大连接数 。proxysql_max_connections:  类型：string, 描述:  每个用户的最大连接数。tidb_gc:  类型：string, 描述:   tikv_gc_life_time。
        - **Value** (str) - 对应修改的参数值: string


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.SetTiDBConfigRequestSchema().dumps(d)

        resp = self.invoke("SetTiDBConfig", d, **kwargs)
        return apis.SetTiDBConfigResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.udisk.schemas import models

""" UDisk API Schema
"""


"""
API: AttachUDisk

将一个可用的UDisk挂载到某台主机上，当UDisk挂载成功后，还需要在主机内部进行文件系统操作
"""


class AttachUDiskRequestSchema(schema.RequestSchema):
    """AttachUDisk - 将一个可用的UDisk挂载到某台主机上，当UDisk挂载成功后，还需要在主机内部进行文件系统操作"""

    fields = {
        "HostId": fields.Str(required=False, dump_to="HostId"),
        "MultiAttach": fields.Str(required=False, dump_to="MultiAttach"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "UHostId": fields.Str(required=False, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class AttachUDiskResponseSchema(schema.ResponseSchema):
    """AttachUDisk - 将一个可用的UDisk挂载到某台主机上，当UDisk挂载成功后，还需要在主机内部进行文件系统操作"""

    fields = {
        "DeviceName": fields.Str(required=False, load_from="DeviceName"),
        "HostId": fields.Str(required=False, load_from="HostId"),
        "UDiskId": fields.Str(required=False, load_from="UDiskId"),
        "UHostId": fields.Str(required=False, load_from="UHostId"),
    }


"""
API: CloneUDisk

从UDisk创建UDisk克隆
"""


class CloneUDiskRequestSchema(schema.RequestSchema):
    """CloneUDisk - 从UDisk创建UDisk克隆"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "Comment": fields.Str(required=False, dump_to="Comment"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "HostId": fields.Str(required=False, dump_to="HostId"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "RdmaClusterId": fields.Str(required=False, dump_to="RdmaClusterId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SnapshotService": fields.Str(
            required=False, dump_to="SnapshotService"
        ),
        "SourceId": fields.Str(required=True, dump_to="SourceId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UDataArkMode": fields.Str(required=False, dump_to="UDataArkMode"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CloneUDiskResponseSchema(schema.ResponseSchema):
    """CloneUDisk - 从UDisk创建UDisk克隆"""

    fields = {
        "UDiskId": fields.List(
            fields.Str(), required=False, load_from="UDiskId"
        ),
    }


"""
API: CloneUDiskSnapshot

从快照创建UDisk克隆
"""


class CloneUDiskSnapshotRequestSchema(schema.RequestSchema):
    """CloneUDiskSnapshot - 从快照创建UDisk克隆"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "Comment": fields.Str(required=False, dump_to="Comment"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "HostId": fields.Str(required=False, dump_to="HostId"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "RdmaClusterId": fields.Str(required=False, dump_to="RdmaClusterId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Size": fields.Int(required=False, dump_to="Size"),
        "SnapshotService": fields.Str(
            required=False, dump_to="SnapshotService"
        ),
        "SourceId": fields.Str(required=True, dump_to="SourceId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UDataArkMode": fields.Str(required=False, dump_to="UDataArkMode"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CloneUDiskSnapshotResponseSchema(schema.ResponseSchema):
    """CloneUDiskSnapshot - 从快照创建UDisk克隆"""

    fields = {
        "UDiskId": fields.List(
            fields.Str(), required=False, load_from="UDiskId"
        ),
    }


"""
API: CloneUDiskUDataArk

从数据方舟的备份创建UDisk
"""


class CloneUDiskUDataArkRequestSchema(schema.RequestSchema):
    """CloneUDiskUDataArk - 从数据方舟的备份创建UDisk"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "Comment": fields.Str(required=False, dump_to="Comment"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "HostId": fields.Str(required=False, dump_to="HostId"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "RdmaClusterId": fields.Str(required=False, dump_to="RdmaClusterId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Size": fields.Int(required=False, dump_to="Size"),
        "SnapshotService": fields.Str(
            required=False, dump_to="SnapshotService"
        ),
        "SnapshotTime": fields.Int(required=True, dump_to="SnapshotTime"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UDataArkMode": fields.Str(required=False, dump_to="UDataArkMode"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CloneUDiskUDataArkResponseSchema(schema.ResponseSchema):
    """CloneUDiskUDataArk - 从数据方舟的备份创建UDisk"""

    fields = {
        "UDiskId": fields.List(
            fields.Str(), required=True, load_from="UDiskId"
        ),
    }


"""
API: CreateAttachUDisk

创建并挂载UDisk磁盘
"""


class CreateAttachUDiskRequestSchema(schema.RequestSchema):
    """CreateAttachUDisk - 创建并挂载UDisk磁盘"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CmkId": fields.Str(required=False, dump_to="CmkId"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DiskType": fields.Str(required=False, dump_to="DiskType"),
        "HostId": fields.Str(required=False, dump_to="HostId"),
        "MultiAttach": fields.Str(required=False, dump_to="MultiAttach"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Size": fields.Int(required=True, dump_to="Size"),
        "SnapshotService": fields.Str(
            required=False, dump_to="SnapshotService"
        ),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UDataArkMode": fields.Str(required=False, dump_to="UDataArkMode"),
        "UHostId": fields.Str(required=False, dump_to="UHostId"),
        "UKmsMode": fields.Str(required=False, dump_to="UKmsMode"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateAttachUDiskResponseSchema(schema.ResponseSchema):
    """CreateAttachUDisk - 创建并挂载UDisk磁盘"""

    fields = {
        "DeviceName": fields.Str(required=False, load_from="DeviceName"),
        "HostId": fields.Str(required=False, load_from="HostId"),
        "UDiskId": fields.Str(required=False, load_from="UDiskId"),
        "UHostId": fields.Str(required=False, load_from="UHostId"),
    }


"""
API: CreateUDisk

创建UDisk磁盘
"""


class CreateUDiskRequestSchema(schema.RequestSchema):
    """CreateUDisk - 创建UDisk磁盘"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CmkId": fields.Str(required=False, dump_to="CmkId"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DiskType": fields.Str(required=False, dump_to="DiskType"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "RdmaClusterId": fields.Str(required=False, dump_to="RdmaClusterId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Size": fields.Int(required=True, dump_to="Size"),
        "SnapshotService": fields.Str(
            required=False, dump_to="SnapshotService"
        ),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UDataArkMode": fields.Str(required=False, dump_to="UDataArkMode"),
        "UKmsMode": fields.Str(required=False, dump_to="UKmsMode"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUDiskResponseSchema(schema.ResponseSchema):
    """CreateUDisk - 创建UDisk磁盘"""

    fields = {
        "UDiskId": fields.List(
            fields.Str(), required=False, load_from="UDiskId"
        ),
    }


"""
API: CreateUDiskSnapshot

创建snapshot快照
"""


class CreateUDiskSnapshotRequestSchema(schema.RequestSchema):
    """CreateUDiskSnapshot - 创建snapshot快照"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "Comment": fields.Str(required=False, dump_to="Comment"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUDiskSnapshotResponseSchema(schema.ResponseSchema):
    """CreateUDiskSnapshot - 创建snapshot快照"""

    fields = {
        "SnapshotId": fields.List(
            fields.Str(), required=True, load_from="SnapshotId"
        ),
    }


"""
API: DeleteUDisk

删除UDisk
"""


class DeleteUDiskRequestSchema(schema.RequestSchema):
    """DeleteUDisk - 删除UDisk"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUDiskResponseSchema(schema.ResponseSchema):
    """DeleteUDisk - 删除UDisk"""

    fields = {}


"""
API: DeleteUDiskSnapshot

删除Snapshot
"""


class DeleteUDiskSnapshotRequestSchema(schema.RequestSchema):
    """DeleteUDiskSnapshot - 删除Snapshot"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SnapshotId": fields.Str(required=False, dump_to="SnapshotId"),
        "UDiskId": fields.Str(required=False, dump_to="UDiskId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUDiskSnapshotResponseSchema(schema.ResponseSchema):
    """DeleteUDiskSnapshot - 删除Snapshot"""

    fields = {}


"""
API: DescribeRecycleUDisk

拉取回收站中云硬盘列表
"""


class DescribeRecycleUDiskRequestSchema(schema.RequestSchema):
    """DescribeRecycleUDisk - 拉取回收站中云硬盘列表"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeRecycleUDiskResponseSchema(schema.ResponseSchema):
    """DescribeRecycleUDisk - 拉取回收站中云硬盘列表"""

    fields = {
        "DataSet": fields.List(
            models.RecycleUDiskSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeUDisk

获取UDisk实例
"""


class DescribeUDiskRequestSchema(schema.RequestSchema):
    """DescribeUDisk - 获取UDisk实例"""

    fields = {
        "DiskType": fields.Str(required=False, dump_to="DiskType"),
        "HostId": fields.Str(required=False, dump_to="HostId"),
        "HostIdForAttachment": fields.Str(
            required=False, dump_to="HostIdForAttachment"
        ),
        "HostProduct": fields.Str(required=False, dump_to="HostProduct"),
        "IgnoreBackupMode": fields.Str(
            required=False, dump_to="IgnoreBackupMode"
        ),
        "IgnoreUBillInfo": fields.Str(
            required=False, dump_to="IgnoreUBillInfo"
        ),
        "IsBoot": fields.Str(required=False, dump_to="IsBoot"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ProtocolVersion": fields.Int(
            required=False, dump_to="ProtocolVersion"
        ),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDiskBasicInfo": fields.Str(required=False, dump_to="UDiskBasicInfo"),
        "UDiskId": fields.Str(required=False, dump_to="UDiskId"),
        "UHostIdForAttachment": fields.Str(
            required=False, dump_to="UHostIdForAttachment"
        ),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDiskResponseSchema(schema.ResponseSchema):
    """DescribeUDisk - 获取UDisk实例"""

    fields = {
        "DataSet": fields.List(
            models.UDiskDataSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUDiskPrice

获取UDisk实例价格信息
"""


class DescribeUDiskPriceRequestSchema(schema.RequestSchema):
    """DescribeUDiskPrice - 获取UDisk实例价格信息"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "DiskType": fields.Str(required=False, dump_to="DiskType"),
        "IsTotalPrice": fields.Str(required=False, dump_to="IsTotalPrice"),
        "MachineType": fields.Str(required=False, dump_to="MachineType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Size": fields.Int(required=True, dump_to="Size"),
        "SnapshotService": fields.Str(
            required=False, dump_to="SnapshotService"
        ),
        "UDataArkMode": fields.Str(required=False, dump_to="UDataArkMode"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDiskPriceResponseSchema(schema.ResponseSchema):
    """DescribeUDiskPrice - 获取UDisk实例价格信息"""

    fields = {
        "DataSet": fields.List(
            models.UDiskPriceDataSetSchema(),
            required=False,
            load_from="DataSet",
        ),
    }


"""
API: DescribeUDiskSnapshot

获取UDisk快照
"""


class DescribeUDiskSnapshotRequestSchema(schema.RequestSchema):
    """DescribeUDiskSnapshot - 获取UDisk快照"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SnapshotId": fields.Str(required=False, dump_to="SnapshotId"),
        "UDiskId": fields.Str(required=False, dump_to="UDiskId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDiskSnapshotResponseSchema(schema.ResponseSchema):
    """DescribeUDiskSnapshot - 获取UDisk快照"""

    fields = {
        "DataSet": fields.List(
            models.UDiskSnapshotSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUDiskUpgradePrice

获取UDisk升级价格信息
"""


class DescribeUDiskUpgradePriceRequestSchema(schema.RequestSchema):
    """DescribeUDiskUpgradePrice - 获取UDisk升级价格信息"""

    fields = {
        "DiskType": fields.Str(required=False, dump_to="DiskType"),
        "MachineType": fields.Str(required=False, dump_to="MachineType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Size": fields.Int(required=True, dump_to="Size"),
        "SnapshotService": fields.Str(
            required=False, dump_to="SnapshotService"
        ),
        "SourceId": fields.Str(required=True, dump_to="SourceId"),
        "UDataArkMode": fields.Str(required=False, dump_to="UDataArkMode"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDiskUpgradePriceResponseSchema(schema.ResponseSchema):
    """DescribeUDiskUpgradePrice - 获取UDisk升级价格信息"""

    fields = {
        "OriginalPrice": fields.Int(required=False, load_from="OriginalPrice"),
        "Price": fields.Int(required=False, load_from="Price"),
    }


"""
API: DetachUDisk

卸载某个已经挂载在指定UHost实例上的UDisk
"""


class DetachUDiskRequestSchema(schema.RequestSchema):
    """DetachUDisk - 卸载某个已经挂载在指定UHost实例上的UDisk"""

    fields = {
        "HostId": fields.Str(required=False, dump_to="HostId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "UHostId": fields.Str(required=False, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DetachUDiskResponseSchema(schema.ResponseSchema):
    """DetachUDisk - 卸载某个已经挂载在指定UHost实例上的UDisk"""

    fields = {
        "HostId": fields.Str(required=False, load_from="HostId"),
        "UDiskId": fields.Str(required=False, load_from="UDiskId"),
        "UHostId": fields.Str(required=False, load_from="UHostId"),
    }


"""
API: RecoverUDisk

从回收站中恢复云硬盘
"""


class RecoverUDiskRequestSchema(schema.RequestSchema):
    """RecoverUDisk - 从回收站中恢复云硬盘"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class RecoverUDiskResponseSchema(schema.ResponseSchema):
    """RecoverUDisk - 从回收站中恢复云硬盘"""

    fields = {}


"""
API: RenameUDisk

重命名UDisk
"""


class RenameUDiskRequestSchema(schema.RequestSchema):
    """RenameUDisk - 重命名UDisk"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "UDiskName": fields.Str(required=True, dump_to="UDiskName"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class RenameUDiskResponseSchema(schema.ResponseSchema):
    """RenameUDisk - 重命名UDisk"""

    fields = {}


"""
API: ResizeUDisk

调整UDisk容量
"""


class ResizeUDiskRequestSchema(schema.RequestSchema):
    """ResizeUDisk - 调整UDisk容量"""

    fields = {
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "MachineType": fields.Str(required=False, dump_to="MachineType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Size": fields.Int(required=True, dump_to="Size"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class ResizeUDiskResponseSchema(schema.ResponseSchema):
    """ResizeUDisk - 调整UDisk容量"""

    fields = {}


"""
API: RestoreUDisk

从备份恢复数据至UDisk
"""


class RestoreUDiskRequestSchema(schema.RequestSchema):
    """RestoreUDisk - 从备份恢复数据至UDisk"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SnapshotId": fields.Str(required=False, dump_to="SnapshotId"),
        "SnapshotTime": fields.Int(required=False, dump_to="SnapshotTime"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class RestoreUDiskResponseSchema(schema.ResponseSchema):
    """RestoreUDisk - 从备份恢复数据至UDisk"""

    fields = {}


"""
API: SetUDiskUDataArkMode

设置UDisk数据方舟的状态
"""


class SetUDiskUDataArkModeRequestSchema(schema.RequestSchema):
    """SetUDiskUDataArkMode - 设置UDisk数据方舟的状态"""

    fields = {
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDataArkMode": fields.Str(required=False, dump_to="UDataArkMode"),
        "UDiskId": fields.Str(required=True, dump_to="UDiskId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class SetUDiskUDataArkModeResponseSchema(schema.ResponseSchema):
    """SetUDiskUDataArkMode - 设置UDisk数据方舟的状态"""

    fields = {}



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class KeyPairSchema(schema.ResponseSchema):
    """KeyPair - 密钥对信息"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "KeyPairFingerPrint": fields.Str(
            required=False, load_from="KeyPairFingerPrint"
        ),
        "KeyPairId": fields.Str(required=False, load_from="KeyPairId"),
        "KeyPairName": fields.Str(required=False, load_from="KeyPairName"),
        "PrivateKeyBody": fields.Str(
            required=False, load_from="PrivateKeyBody"
        ),
        "ProjectId": fields.Str(required=False, load_from="ProjectId"),
    }


class FeatureModesSchema(schema.ResponseSchema):
    """FeatureModes - 可以支持的模式类别"""

    fields = {
        "MinimalCpuPlatform": fields.List(fields.Str()),
        "Name": fields.Str(required=False, load_from="Name"),
        "RelatedToImageFeature": fields.List(fields.Str()),
    }


class CollectionSchema(schema.ResponseSchema):
    """Collection - CPU和内存可支持的规格"""

    fields = {
        "Cpu": fields.Int(required=False, load_from="Cpu"),
        "Memory": fields.List(fields.Int()),
        "MinimalCpuPlatform": fields.List(fields.Str()),
    }


class DataDiskInfoSchema(schema.ResponseSchema):
    """DataDiskInfo - 数据盘信息"""

    fields = {
        "Features": fields.List(fields.Str()),
        "MaximalSize": fields.Int(required=False, load_from="MaximalSize"),
        "MinimalSize": fields.Int(required=False, load_from="MinimalSize"),
        "Name": fields.Str(required=False, load_from="Name"),
    }


class BootDiskInfoSchema(schema.ResponseSchema):
    """BootDiskInfo - 系统盘信息"""

    fields = {
        "Features": fields.List(fields.Str()),
        "InstantResize": fields.Bool(required=False, load_from="InstantResize"),
        "MaximalSize": fields.Int(required=False, load_from="MaximalSize"),
        "Name": fields.Str(required=False, load_from="Name"),
    }


class FeaturesSchema(schema.ResponseSchema):
    """Features - 虚机可支持的特性"""

    fields = {
        "Modes": fields.List(FeatureModesSchema()),
        "Name": fields.Str(required=False, load_from="Name"),
    }


class CpuPlatformsSchema(schema.ResponseSchema):
    """CpuPlatforms - CPU平台信息"""

    fields = {
        "Amd": fields.List(fields.Str()),
        "Ampere": fields.List(fields.Str()),
        "Intel": fields.List(fields.Str()),
    }


class GraphicsMemorySchema(schema.ResponseSchema):
    """GraphicsMemory - GPU的显存指标"""

    fields = {
        "Rate": fields.Int(required=False, load_from="Rate"),
        "Value": fields.Int(required=False, load_from="Value"),
    }


class MachineSizesSchema(schema.ResponseSchema):
    """MachineSizes - GPU、CPU和内存信息"""

    fields = {
        "Collection": fields.List(CollectionSchema()),
        "Gpu": fields.Int(required=False, load_from="Gpu"),
    }


class DisksSchema(schema.ResponseSchema):
    """Disks - 磁盘信息"""

    fields = {
        "BootDisk": fields.List(BootDiskInfoSchema()),
        "DataDisk": fields.List(DataDiskInfoSchema()),
        "Name": fields.Str(required=False, load_from="Name"),
    }


class PerformanceSchema(schema.ResponseSchema):
    """Performance - GPU的性能指标"""

    fields = {
        "Rate": fields.Int(required=False, load_from="Rate"),
        "Value": fields.Int(required=False, load_from="Value"),
    }


class AvailableInstanceTypesSchema(schema.ResponseSchema):
    """AvailableInstanceTypes - https://ushare.ucloudadmin.com/pages/viewpage.action?pageId=104662646"""

    fields = {
        "CpuPlatforms": CpuPlatformsSchema(),
        "Disks": fields.List(DisksSchema()),
        "Features": fields.List(FeaturesSchema()),
        "GraphicsMemory": GraphicsMemorySchema(),
        "MachineClass": fields.Str(required=False, load_from="MachineClass"),
        "MachineSizes": fields.List(MachineSizesSchema()),
        "Name": fields.Str(required=False, load_from="Name"),
        "Performance": PerformanceSchema(),
        "Status": fields.Str(required=False, load_from="Status"),
    }


class UHostImageSetSchema(schema.ResponseSchema):
    """UHostImageSet - DescribeImage"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "Features": fields.List(fields.Str()),
        "FuncType": fields.Str(required=False, load_from="FuncType"),
        "ImageDescription": fields.Str(
            required=False, load_from="ImageDescription"
        ),
        "ImageId": fields.Str(required=False, load_from="ImageId"),
        "ImageName": fields.Str(required=False, load_from="ImageName"),
        "ImageSize": fields.Int(required=False, load_from="ImageSize"),
        "ImageType": fields.Str(required=False, load_from="ImageType"),
        "IntegratedSoftware": fields.Str(
            required=False, load_from="IntegratedSoftware"
        ),
        "Links": fields.Str(required=False, load_from="Links"),
        "MinimalCPU": fields.Str(required=False, load_from="MinimalCPU"),
        "OsName": fields.Str(required=False, load_from="OsName"),
        "OsType": fields.Str(required=False, load_from="OsType"),
        "State": fields.Str(required=False, load_from="State"),
        "Vendor": fields.Str(required=False, load_from="Vendor"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class SpreadInfoSchema(schema.ResponseSchema):
    """SpreadInfo - 每个可用区中硬件隔离组信息"""

    fields = {
        "UHostCount": fields.Int(required=False, load_from="UHostCount"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class IsolationGroupSchema(schema.ResponseSchema):
    """IsolationGroup - 硬件隔离组信息"""

    fields = {
        "GroupId": fields.Str(required=False, load_from="GroupId"),
        "GroupName": fields.Str(required=False, load_from="GroupName"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "SpreadInfoSet": fields.List(SpreadInfoSchema()),
    }


class UHostKeyPairSchema(schema.ResponseSchema):
    """UHostKeyPair - 主机密钥信息"""

    fields = {
        "KeyPairId": fields.Str(required=False, load_from="KeyPairId"),
        "KeyPairState": fields.Str(required=False, load_from="KeyPairState"),
    }


class UHostIPSetSchema(schema.ResponseSchema):
    """UHostIPSet - DescribeUHostInstance"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "Default": fields.Str(required=False, load_from="Default"),
        "IP": fields.Str(required=False, load_from="IP"),
        "IPId": fields.Str(required=False, load_from="IPId"),
        "IPMode": fields.Str(required=True, load_from="IPMode"),
        "Mac": fields.Str(required=False, load_from="Mac"),
        "NetworkInterfaceId": fields.Str(
            required=False, load_from="NetworkInterfaceId"
        ),
        "SubnetId": fields.Str(required=False, load_from="SubnetId"),
        "Type": fields.Str(required=False, load_from="Type"),
        "VPCId": fields.Str(required=False, load_from="VPCId"),
        "Weight": fields.Int(required=False, load_from="Weight"),
    }


class UHostDiskSetSchema(schema.ResponseSchema):
    """UHostDiskSet - DescribeUHostInstance"""

    fields = {
        "BackupType": fields.Str(required=False, load_from="BackupType"),
        "DiskId": fields.Str(required=False, load_from="DiskId"),
        "DiskType": fields.Str(required=True, load_from="DiskType"),
        "Drive": fields.Str(required=False, load_from="Drive"),
        "Encrypted": fields.Str(required=False, load_from="Encrypted"),
        "IsBoot": fields.Str(required=True, load_from="IsBoot"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Size": fields.Int(required=False, load_from="Size"),
        "Type": fields.Str(required=False, load_from="Type"),
    }


class UHostInstanceSetSchema(schema.ResponseSchema):
    """UHostInstanceSet - DescribeUHostInstance"""

    fields = {
        "AutoRenew": fields.Str(required=False, load_from="AutoRenew"),
        "BasicImageId": fields.Str(required=False, load_from="BasicImageId"),
        "BasicImageName": fields.Str(
            required=False, load_from="BasicImageName"
        ),
        "BootDiskState": fields.Str(required=False, load_from="BootDiskState"),
        "CPU": fields.Int(required=False, load_from="CPU"),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "CloudInitFeature": fields.Bool(
            required=False, load_from="CloudInitFeature"
        ),
        "CpuPlatform": fields.Str(required=False, load_from="CpuPlatform"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DiskSet": fields.List(UHostDiskSetSchema()),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "GPU": fields.Int(required=False, load_from="GPU"),
        "HostType": fields.Str(required=False, load_from="HostType"),
        "HotplugFeature": fields.Bool(
            required=False, load_from="HotplugFeature"
        ),
        "HpcFeature": fields.Bool(required=False, load_from="HpcFeature"),
        "IPSet": fields.List(UHostIPSetSchema()),
        "IPv6Feature": fields.Bool(required=False, load_from="IPv6Feature"),
        "ImageId": fields.Str(required=False, load_from="ImageId"),
        "IsolationGroup": fields.Str(
            required=False, load_from="IsolationGroup"
        ),
        "KeyPair": UHostKeyPairSchema(),
        "LifeCycle": fields.Str(required=False, load_from="LifeCycle"),
        "MachineType": fields.Str(required=False, load_from="MachineType"),
        "Memory": fields.Int(required=False, load_from="Memory"),
        "Name": fields.Str(required=False, load_from="Name"),
        "NetCapability": fields.Str(required=False, load_from="NetCapability"),
        "NetworkState": fields.Str(required=False, load_from="NetworkState"),
        "OsName": fields.Str(required=False, load_from="OsName"),
        "OsType": fields.Str(required=False, load_from="OsType"),
        "RdmaClusterId": fields.Str(required=False, load_from="RdmaClusterId"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "RestrictMode": fields.Str(required=False, load_from="RestrictMode"),
        "State": fields.Str(required=False, load_from="State"),
        "StorageType": fields.Str(required=False, load_from="StorageType"),
        "SubnetType": fields.Str(required=False, load_from="SubnetType"),
        "Tag": fields.Str(required=False, load_from="Tag"),
        "TimemachineFeature": fields.Str(
            required=False, load_from="TimemachineFeature"
        ),
        "TotalDiskSpace": fields.Int(
            required=False, load_from="TotalDiskSpace"
        ),
        "UHostId": fields.Str(required=False, load_from="UHostId"),
        "UHostType": fields.Str(required=False, load_from="UHostType"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class UHostSnapshotSetSchema(schema.ResponseSchema):
    """UHostSnapshotSet -"""

    fields = {
        "SnapshotName": fields.Str(required=False, load_from="SnapshotName"),
        "SnapshotState": fields.Str(required=False, load_from="SnapshotState"),
        "SnapshotTime": fields.Str(required=False, load_from="SnapshotTime"),
    }


class KeyPairDescSchema(schema.ResponseSchema):
    """KeyPairDesc - 密钥对信息，不包含私钥内容。"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "KeyPairFingerPrint": fields.Str(
            required=False, load_from="KeyPairFingerPrint"
        ),
        "KeyPairId": fields.Str(required=False, load_from="KeyPairId"),
        "KeyPairName": fields.Str(required=False, load_from="KeyPairName"),
        "ProjectId": fields.Str(required=False, load_from="ProjectId"),
    }


class UHostTagSetSchema(schema.ResponseSchema):
    """UHostTagSet - DescribeUHostTags"""

    fields = {
        "Tag": fields.Str(required=False, load_from="Tag"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class UHostPriceSetSchema(schema.ResponseSchema):
    """UHostPriceSet - 主机价格"""

    fields = {
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "ListPrice": fields.Float(required=False, load_from="ListPrice"),
        "OriginalPrice": fields.Float(required=True, load_from="OriginalPrice"),
        "Price": fields.Float(required=True, load_from="Price"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uec.schemas import models

""" UEC API Schema
"""


"""
API: BindUEcFirewall

绑定防火墙，应用防火墙规则
"""


class BindUEcFirewallRequestSchema(schema.RequestSchema):
    """BindUEcFirewall - 绑定防火墙，应用防火墙规则"""

    fields = {
        "FirewallId": fields.Str(required=True, dump_to="FirewallId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
    }


class BindUEcFirewallResponseSchema(schema.ResponseSchema):
    """BindUEcFirewall - 绑定防火墙，应用防火墙规则"""

    fields = {}


"""
API: CreateUEcCustomImage

从指定虚拟机，生成自定义镜像。
"""


class CreateUEcCustomImageRequestSchema(schema.RequestSchema):
    """CreateUEcCustomImage - 从指定虚拟机，生成自定义镜像。"""

    fields = {
        "ImageDescription": fields.Str(
            required=False, dump_to="ImageDescription"
        ),
        "ImageName": fields.Str(required=True, dump_to="ImageName"),
        "NodeId": fields.Str(required=True, dump_to="NodeId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class CreateUEcCustomImageResponseSchema(schema.ResponseSchema):
    """CreateUEcCustomImage - 从指定虚拟机，生成自定义镜像。"""

    fields = {
        "ImageId": fields.Str(required=True, load_from="ImageId"),
    }


"""
API: CreateUEcFirewall

创建外网防火墙
"""


class CreateUEcFirewallParamRuleSchema(schema.RequestSchema):
    """CreateUEcFirewallParamRule -"""

    fields = {
        "Action": fields.Str(required=True, dump_to="Action"),
        "Port": fields.Str(required=True, dump_to="Port"),
        "Priority": fields.Str(required=True, dump_to="Priority"),
        "ProtocolType": fields.Str(required=True, dump_to="ProtocolType"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "SrcIp": fields.Str(required=True, dump_to="SrcIp"),
    }


class CreateUEcFirewallRequestSchema(schema.RequestSchema):
    """CreateUEcFirewall - 创建外网防火墙"""

    fields = {
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Rule": fields.List(CreateUEcFirewallParamRuleSchema()),
    }


class CreateUEcFirewallResponseSchema(schema.ResponseSchema):
    """CreateUEcFirewall - 创建外网防火墙"""

    fields = {
        "FirewallId": fields.Str(required=True, load_from="FirewallId"),
    }


"""
API: CreateUEcHolder

创建容器组
"""


class CreateUEcHolderParamImageSchema(schema.RequestSchema):
    """CreateUEcHolderParamImage -"""

    fields = {
        "Message": fields.Str(required=False, dump_to="Message"),
        "StoreAddress": fields.Str(required=False, dump_to="StoreAddress"),
    }


class CreateUEcHolderParamPackSchema(schema.RequestSchema):
    """CreateUEcHolderParamPack -"""

    fields = {
        "Args": fields.Str(required=False, dump_to="Args"),
        "Cmd": fields.Str(required=False, dump_to="Cmd"),
        "ConfigDict": fields.Str(required=False, dump_to="ConfigDict"),
        "CpuCore": fields.Float(required=False, dump_to="CpuCore"),
        "Environment": fields.Str(required=False, dump_to="Environment"),
        "ImageName": fields.Str(required=False, dump_to="ImageName"),
        "MemSize": fields.Int(required=False, dump_to="MemSize"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "WorkDir": fields.Str(required=False, dump_to="WorkDir"),
    }


class CreateUEcHolderParamStorageSchema(schema.RequestSchema):
    """CreateUEcHolderParamStorage -"""

    fields = {
        "Path": fields.Str(required=False, dump_to="Path"),
        "ResourceId": fields.Str(required=False, dump_to="ResourceId"),
    }


class CreateUEcHolderRequestSchema(schema.RequestSchema):
    """CreateUEcHolder - 创建容器组"""

    fields = {
        "Bandwidth": fields.Int(required=False, dump_to="Bandwidth"),
        "ChargeQuantity": fields.Int(required=False, dump_to="ChargeQuantity"),
        "ChargeType": fields.Int(required=False, dump_to="ChargeType"),
        "CpuCore": fields.Float(required=True, dump_to="CpuCore"),
        "ElasticIp": fields.Str(required=False, dump_to="ElasticIp"),
        "FirewallId": fields.Str(required=False, dump_to="FirewallId"),
        "IdcId": fields.Str(required=True, dump_to="IdcId"),
        "Image": fields.List(CreateUEcHolderParamImageSchema()),
        "MemSize": fields.Int(required=True, dump_to="MemSize"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "Pack": fields.List(CreateUEcHolderParamPackSchema()),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RestartStrategy": fields.Int(
            required=False, dump_to="RestartStrategy"
        ),
        "Storage": fields.List(CreateUEcHolderParamStorageSchema()),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class CreateUEcHolderResponseSchema(schema.ResponseSchema):
    """CreateUEcHolder - 创建容器组"""

    fields = {
        "ResourceId": fields.Str(required=False, load_from="ResourceId"),
    }


"""
API: CreateUEcSubnet

创建子网
"""


class CreateUEcSubnetRequestSchema(schema.RequestSchema):
    """CreateUEcSubnet - 创建子网"""

    fields = {
        "CIDR": fields.Str(required=True, dump_to="CIDR"),
        "Comment": fields.Str(required=False, dump_to="Comment"),
        "IdcId": fields.Str(required=True, dump_to="IdcId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SubnetName": fields.Str(required=False, dump_to="SubnetName"),
    }


class CreateUEcSubnetResponseSchema(schema.ResponseSchema):
    """CreateUEcSubnet - 创建子网"""

    fields = {
        "SubnetId": fields.Str(required=True, load_from="SubnetId"),
    }


"""
API: CreateUEcVHost

创建虚拟机v2.0
"""


class CreateUEcVHostRequestSchema(schema.RequestSchema):
    """CreateUEcVHost - 创建虚拟机v2.0"""

    fields = {
        "AccountName": fields.Str(required=False, dump_to="AccountName"),
        "ChargeQuantity": fields.Int(required=False, dump_to="ChargeQuantity"),
        "ChargeType": fields.Int(required=False, dump_to="ChargeType"),
        "CpuCore": fields.Int(required=True, dump_to="CpuCore"),
        "DiskSize": fields.Int(required=True, dump_to="DiskSize"),
        "FirewallId": fields.Str(required=False, dump_to="FirewallId"),
        "Gpu": fields.Int(required=False, dump_to="Gpu"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "IdcId": fields.Str(required=True, dump_to="IdcId"),
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "IsNeedOuterIp": fields.Str(required=False, dump_to="IsNeedOuterIp"),
        "Isp": fields.List(fields.Int()),
        "MemSize": fields.Int(required=True, dump_to="MemSize"),
        "NetLimit": fields.Int(required=True, dump_to="NetLimit"),
        "NodeCount": fields.Int(required=False, dump_to="NodeCount"),
        "NodeName": fields.Str(required=False, dump_to="NodeName"),
        "PassWord": fields.Str(required=False, dump_to="PassWord"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "SysDiskSize": fields.Int(required=False, dump_to="SysDiskSize"),
    }


class CreateUEcVHostResponseSchema(schema.ResponseSchema):
    """CreateUEcVHost - 创建虚拟机v2.0"""

    fields = {
        "NodeList": fields.List(
            models.NodeListSchema(), required=True, load_from="NodeList"
        ),
    }


"""
API: DeleteUEcCustomImage

删除UEDN客户自定义镜像
"""


class DeleteUEcCustomImageRequestSchema(schema.RequestSchema):
    """DeleteUEcCustomImage - 删除UEDN客户自定义镜像"""

    fields = {
        "IdcId": fields.Str(required=False, dump_to="IdcId"),
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DeleteUEcCustomImageResponseSchema(schema.ResponseSchema):
    """DeleteUEcCustomImage - 删除UEDN客户自定义镜像"""

    fields = {
        "ImageId": fields.Int(required=True, load_from="ImageId"),
    }


"""
API: DeleteUEcHolder

删除容器组
"""


class DeleteUEcHolderRequestSchema(schema.RequestSchema):
    """DeleteUEcHolder - 删除容器组"""

    fields = {
        "HolderId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DeleteUEcHolderResponseSchema(schema.ResponseSchema):
    """DeleteUEcHolder - 删除容器组"""

    fields = {}


"""
API: DeleteUEcSubnet

删除子网
"""


class DeleteUEcSubnetRequestSchema(schema.RequestSchema):
    """DeleteUEcSubnet - 删除子网"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class DeleteUEcSubnetResponseSchema(schema.ResponseSchema):
    """DeleteUEcSubnet - 删除子网"""

    fields = {}


"""
API: DeleteUEcVHost

删除vhost虚拟机 v2.0
"""


class DeleteUEcVHostRequestSchema(schema.RequestSchema):
    """DeleteUEcVHost - 删除vhost虚拟机 v2.0"""

    fields = {
        "NodeId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DeleteUEcVHostResponseSchema(schema.ResponseSchema):
    """DeleteUEcVHost - 删除vhost虚拟机 v2.0"""

    fields = {}


"""
API: DescribeUEcFirewall

获取防火墙信息
"""


class DescribeUEcFirewallRequestSchema(schema.RequestSchema):
    """DescribeUEcFirewall - 获取防火墙信息"""

    fields = {
        "FirewallId": fields.Str(required=False, dump_to="FirewallId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ResourceId": fields.Str(required=False, dump_to="ResourceId"),
    }


class DescribeUEcFirewallResponseSchema(schema.ResponseSchema):
    """DescribeUEcFirewall - 获取防火墙信息"""

    fields = {
        "FirewallSet": fields.List(
            models.FirewallInfoSchema(), required=False, load_from="FirewallSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUEcFirewallResource

防火墙绑定的资源列表
"""


class DescribeUEcFirewallResourceRequestSchema(schema.RequestSchema):
    """DescribeUEcFirewallResource - 防火墙绑定的资源列表"""

    fields = {
        "FirewallId": fields.Str(required=True, dump_to="FirewallId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DescribeUEcFirewallResourceResponseSchema(schema.ResponseSchema):
    """DescribeUEcFirewallResource - 防火墙绑定的资源列表"""

    fields = {
        "ResourceSet": fields.List(
            models.ResourceInfoSchema(), required=True, load_from="ResourceSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeUEcHolder

获得容器组信息
"""


class DescribeUEcHolderRequestSchema(schema.RequestSchema):
    """DescribeUEcHolder - 获得容器组信息"""

    fields = {
        "HolderId": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DescribeUEcHolderResponseSchema(schema.ResponseSchema):
    """DescribeUEcHolder - 获得容器组信息"""

    fields = {
        "HolderList": fields.List(
            models.HolderListSchema(), required=True, load_from="HolderList"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeUEcHolderIDC

获取容器组机房信息
"""


class DescribeUEcHolderIDCRequestSchema(schema.RequestSchema):
    """DescribeUEcHolderIDC - 获取容器组机房信息"""

    fields = {
        "Cpu": fields.Float(required=True, dump_to="Cpu"),
        "IdcId": fields.List(fields.Str()),
        "Memory": fields.Int(required=True, dump_to="Memory"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=False, dump_to="Type"),
    }


class DescribeUEcHolderIDCResponseSchema(schema.ResponseSchema):
    """DescribeUEcHolderIDC - 获取容器组机房信息"""

    fields = {
        "IdcList": fields.List(
            models.IdcInfoSchema(), required=True, load_from="IdcList"
        ),
    }


"""
API: DescribeUEcIDC

获取IDC机房列表
"""


class DescribeUEcIDCRequestSchema(schema.RequestSchema):
    """DescribeUEcIDC - 获取IDC机房列表"""

    fields = {
        "Cpu": fields.Int(required=True, dump_to="Cpu"),
        "Gpu": fields.Int(required=False, dump_to="Gpu"),
        "IdcId": fields.List(fields.Str()),
        "Memory": fields.Int(required=True, dump_to="Memory"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=False, dump_to="Type"),
    }


class DescribeUEcIDCResponseSchema(schema.ResponseSchema):
    """DescribeUEcIDC - 获取IDC机房列表"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "IdcList": fields.List(
            models.IdcInfoSchema(), required=False, load_from="IdcList"
        ),
        "RetCode": fields.Int(required=True, load_from="RetCode"),
    }


"""
API: DescribeUEcSubnet

获取子网列表
"""


class DescribeUEcSubnetRequestSchema(schema.RequestSchema):
    """DescribeUEcSubnet - 获取子网列表"""

    fields = {
        "IdcId": fields.Str(required=False, dump_to="IdcId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
    }


class DescribeUEcSubnetResponseSchema(schema.ResponseSchema):
    """DescribeUEcSubnet - 获取子网列表"""

    fields = {
        "SubnetList": fields.List(
            models.SubnetInfoSchema(), required=False, load_from="SubnetList"
        ),
    }


"""
API: DescribeUEcVHost

获取虚拟机列表 2.0
"""


class DescribeUEcVHostRequestSchema(schema.RequestSchema):
    """DescribeUEcVHost - 获取虚拟机列表 2.0"""

    fields = {
        "IdcId": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "NodeId": fields.List(fields.Str()),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DescribeUEcVHostResponseSchema(schema.ResponseSchema):
    """DescribeUEcVHost - 获取虚拟机列表 2.0"""

    fields = {
        "NodeList": fields.List(
            models.NodeInfoSchema(), required=False, load_from="NodeList"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUEcVHostISP

获取虚拟机运营商信息
"""


class DescribeUEcVHostISPRequestSchema(schema.RequestSchema):
    """DescribeUEcVHostISP - 获取虚拟机运营商信息"""

    fields = {
        "City": fields.Str(required=False, dump_to="City"),
        "IspName": fields.Str(required=False, dump_to="IspName"),
        "Province": fields.Str(required=False, dump_to="Province"),
    }


class DescribeUEcVHostISPResponseSchema(schema.ResponseSchema):
    """DescribeUEcVHostISP - 获取虚拟机运营商信息"""

    fields = {
        "NodeIspList": fields.List(
            models.NodeIspListSchema(), required=True, load_from="NodeIspList"
        ),
    }


"""
API: GetUEcHolderLog

获取单个容器日志
"""


class GetUEcHolderLogRequestSchema(schema.RequestSchema):
    """GetUEcHolderLog - 获取单个容器日志"""

    fields = {
        "PackName": fields.Str(required=True, dump_to="PackName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
    }


class GetUEcHolderLogResponseSchema(schema.ResponseSchema):
    """GetUEcHolderLog - 获取单个容器日志"""

    fields = {
        "Data": fields.Str(required=False, load_from="Data"),
    }


"""
API: GetUEcHolderMetrics

获取容器（CPU利用率，带宽，内存）数据
"""


class GetUEcHolderMetricsRequestSchema(schema.RequestSchema):
    """GetUEcHolderMetrics - 获取容器（CPU利用率，带宽，内存）数据"""

    fields = {
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "PackName": fields.Str(required=True, dump_to="PackName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
        "StartTime": fields.Int(required=False, dump_to="StartTime"),
        "Type": fields.List(fields.Str()),
    }


class GetUEcHolderMetricsResponseSchema(schema.ResponseSchema):
    """GetUEcHolderMetrics - 获取容器（CPU利用率，带宽，内存）数据"""

    fields = {
        "DataSets": models.MetricisDataSetSchema(),
    }


"""
API: GetUEcIDCCutInfo

获取机房割接信息
"""


class GetUEcIDCCutInfoRequestSchema(schema.RequestSchema):
    """GetUEcIDCCutInfo - 获取机房割接信息"""

    fields = {}


class GetUEcIDCCutInfoResponseSchema(schema.ResponseSchema):
    """GetUEcIDCCutInfo - 获取机房割接信息"""

    fields = {
        "IDCCutInfo": fields.List(
            models.IDCCutInfoSchema(), required=True, load_from="IDCCutInfo"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: GetUEcIDCVHostData

获取机房虚拟机监控数据
"""


class GetUEcIDCVHostDataRequestSchema(schema.RequestSchema):
    """GetUEcIDCVHostData - 获取机房虚拟机监控数据"""

    fields = {
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "NodeId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.List(fields.Str()),
    }


class GetUEcIDCVHostDataResponseSchema(schema.ResponseSchema):
    """GetUEcIDCVHostData - 获取机房虚拟机监控数据"""

    fields = {
        "DataSets": models.DataSetSchema(),
    }


"""
API: GetUEcImage

uec2.0
"""


class GetUEcImageRequestSchema(schema.RequestSchema):
    """GetUEcImage - uec2.0"""

    fields = {
        "ImageType": fields.Str(required=False, dump_to="ImageType"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUEcImageResponseSchema(schema.ResponseSchema):
    """GetUEcImage - uec2.0"""

    fields = {
        "ImageList": fields.List(
            models.ImageInfoSchema(), required=False, load_from="ImageList"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: GetUEcPodPrice

获得容器组价格
"""


class GetUEcPodPriceRequestSchema(schema.RequestSchema):
    """GetUEcPodPrice - 获得容器组价格"""

    fields = {
        "Bandwidth": fields.Int(required=False, dump_to="Bandwidth"),
        "ChargeQuantity": fields.Int(required=False, dump_to="ChargeQuantity"),
        "ChargeType": fields.Int(required=False, dump_to="ChargeType"),
        "CpuCore": fields.Float(required=False, dump_to="CpuCore"),
        "ElasticIp": fields.Str(required=False, dump_to="ElasticIp"),
        "IdcId": fields.Str(required=True, dump_to="IdcId"),
        "MemSize": fields.Int(required=False, dump_to="MemSize"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
    }


class GetUEcPodPriceResponseSchema(schema.ResponseSchema):
    """GetUEcPodPrice - 获得容器组价格"""

    fields = {
        "HolderPrice": fields.Float(required=True, load_from="HolderPrice"),
        "IpPrice": fields.Float(required=True, load_from="IpPrice"),
    }


"""
API: GetUEcUpgradePrice

获取虚拟机调整差价
"""


class GetUEcUpgradePriceRequestSchema(schema.RequestSchema):
    """GetUEcUpgradePrice - 获取虚拟机调整差价"""

    fields = {
        "CpuCore": fields.Int(required=False, dump_to="CpuCore"),
        "DiskSize": fields.Int(required=False, dump_to="DiskSize"),
        "MemSize": fields.Int(required=False, dump_to="MemSize"),
        "NetLimit": fields.Int(required=False, dump_to="NetLimit"),
        "NodeId": fields.Str(required=True, dump_to="NodeId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SysDiskSize": fields.Int(required=False, dump_to="SysDiskSize"),
    }


class GetUEcUpgradePriceResponseSchema(schema.ResponseSchema):
    """GetUEcUpgradePrice - 获取虚拟机调整差价"""

    fields = {
        "Price": fields.Int(required=False, load_from="Price"),
    }


"""
API: GetUEcVHostData

获取虚拟机监控数据
"""


class GetUEcVHostDataRequestSchema(schema.RequestSchema):
    """GetUEcVHostData - 获取虚拟机监控数据"""

    fields = {
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "NodeId": fields.Str(required=True, dump_to="NodeId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.List(fields.Int()),
    }


class GetUEcVHostDataResponseSchema(schema.ResponseSchema):
    """GetUEcVHostData - 获取虚拟机监控数据"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "DataSets": models.DataSetSchema(),
        "RetCode": fields.Int(required=True, load_from="RetCode"),
    }


"""
API: GetUEcVHostPrice

获取虚拟机价格
"""


class GetUEcVHostPriceRequestSchema(schema.RequestSchema):
    """GetUEcVHostPrice - 获取虚拟机价格"""

    fields = {
        "ChargeQuantity": fields.Int(required=False, dump_to="ChargeQuantity"),
        "ChargeType": fields.Int(required=False, dump_to="ChargeType"),
        "CpuCore": fields.Int(required=False, dump_to="CpuCore"),
        "DiskSize": fields.Int(required=False, dump_to="DiskSize"),
        "Gpu": fields.Int(required=False, dump_to="Gpu"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "IdcId": fields.Str(required=True, dump_to="IdcId"),
        "IpCount": fields.Int(required=False, dump_to="IpCount"),
        "MemSize": fields.Int(required=False, dump_to="MemSize"),
        "NetLimit": fields.Int(required=False, dump_to="NetLimit"),
        "NodeCount": fields.Int(required=False, dump_to="NodeCount"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "SysDiskSize": fields.Int(required=False, dump_to="SysDiskSize"),
    }


class GetUEcVHostPriceResponseSchema(schema.ResponseSchema):
    """GetUEcVHostPrice - 获取虚拟机价格"""

    fields = {
        "IpPrice": fields.Float(required=False, load_from="IpPrice"),
        "NodePrice": fields.Float(required=False, load_from="NodePrice"),
    }


"""
API: ImportUEcCustomImage

导入自定义镜像
"""


class ImportUEcCustomImageRequestSchema(schema.RequestSchema):
    """ImportUEcCustomImage - 导入自定义镜像"""

    fields = {
        "Format": fields.Str(required=False, dump_to="Format"),
        "IdcId": fields.List(fields.Str()),
        "ImageDesc": fields.Str(required=False, dump_to="ImageDesc"),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "ImageName": fields.Str(required=False, dump_to="ImageName"),
        "OsType": fields.Str(required=False, dump_to="OsType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UFileUrl": fields.Str(required=False, dump_to="UFileUrl"),
    }


class ImportUEcCustomImageResponseSchema(schema.ResponseSchema):
    """ImportUEcCustomImage - 导入自定义镜像"""

    fields = {
        "ImageId": fields.Str(required=True, load_from="ImageId"),
    }


"""
API: LoginUEcDocker

登录容器
"""


class LoginUEcDockerRequestSchema(schema.RequestSchema):
    """LoginUEcDocker - 登录容器"""

    fields = {
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
    }


class LoginUEcDockerResponseSchema(schema.ResponseSchema):
    """LoginUEcDocker - 登录容器"""

    fields = {
        "Link": fields.Str(required=False, load_from="Link"),
        "LinkPort": fields.Int(required=False, load_from="LinkPort"),
        "SessionId": fields.Str(required=True, load_from="SessionId"),
    }


"""
API: ModifyUEcBandwidth

修改节点带宽限制
"""


class ModifyUEcBandwidthRequestSchema(schema.RequestSchema):
    """ModifyUEcBandwidth - 修改节点带宽限制"""

    fields = {
        "NetLimit": fields.Str(required=True, dump_to="NetLimit"),
        "NodeId": fields.Str(required=True, dump_to="NodeId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class ModifyUEcBandwidthResponseSchema(schema.ResponseSchema):
    """ModifyUEcBandwidth - 修改节点带宽限制"""

    fields = {}


"""
API: ModifyUEcHolderName

修改容器组名称
"""


class ModifyUEcHolderNameRequestSchema(schema.RequestSchema):
    """ModifyUEcHolderName - 修改容器组名称"""

    fields = {
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
    }


class ModifyUEcHolderNameResponseSchema(schema.ResponseSchema):
    """ModifyUEcHolderName - 修改容器组名称"""

    fields = {}


"""
API: ModifyUEcImageName

修改镜像名称
"""


class ModifyUEcImageNameRequestSchema(schema.RequestSchema):
    """ModifyUEcImageName - 修改镜像名称"""

    fields = {
        "ImageDesc": fields.Str(required=False, dump_to="ImageDesc"),
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "ImageName": fields.Str(required=True, dump_to="ImageName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class ModifyUEcImageNameResponseSchema(schema.ResponseSchema):
    """ModifyUEcImageName - 修改镜像名称"""

    fields = {}


"""
API: PoweroffUEcVHost

虚拟机断电
"""


class PoweroffUEcVHostRequestSchema(schema.RequestSchema):
    """PoweroffUEcVHost - 虚拟机断电"""

    fields = {
        "NodeId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class PoweroffUEcVHostResponseSchema(schema.ResponseSchema):
    """PoweroffUEcVHost - 虚拟机断电"""

    fields = {}


"""
API: ReinstallUEcVHost

虚拟机重装系统
"""


class ReinstallUEcVHostRequestSchema(schema.RequestSchema):
    """ReinstallUEcVHost - 虚拟机重装系统"""

    fields = {
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "KeepData": fields.Int(required=False, dump_to="KeepData"),
        "NodeId": fields.Str(required=True, dump_to="NodeId"),
        "Password": fields.Str(required=False, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SysDiskSize": fields.Int(required=False, dump_to="SysDiskSize"),
    }


class ReinstallUEcVHostResponseSchema(schema.ResponseSchema):
    """ReinstallUEcVHost - 虚拟机重装系统"""

    fields = {}


"""
API: RestartUEcHolder

重启容器组
"""


class RestartUEcHolderRequestSchema(schema.RequestSchema):
    """RestartUEcHolder - 重启容器组"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ResourceId": fields.List(fields.Str()),
    }


class RestartUEcHolderResponseSchema(schema.ResponseSchema):
    """RestartUEcHolder - 重启容器组"""

    fields = {}


"""
API: RestartUEcVHost

重启虚拟机v2.0
"""


class RestartUEcVHostRequestSchema(schema.RequestSchema):
    """RestartUEcVHost - 重启虚拟机v2.0"""

    fields = {
        "NodeId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class RestartUEcVHostResponseSchema(schema.ResponseSchema):
    """RestartUEcVHost - 重启虚拟机v2.0"""

    fields = {}


"""
API: StartUEcVHost

启动UEC虚拟机
"""


class StartUEcVHostRequestSchema(schema.RequestSchema):
    """StartUEcVHost - 启动UEC虚拟机"""

    fields = {
        "NodeId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class StartUEcVHostResponseSchema(schema.ResponseSchema):
    """StartUEcVHost - 启动UEC虚拟机"""

    fields = {}


"""
API: StopUEcVHost

停止UEC虚拟机
"""


class StopUEcVHostRequestSchema(schema.RequestSchema):
    """StopUEcVHost - 停止UEC虚拟机"""

    fields = {
        "NodeId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class StopUEcVHostResponseSchema(schema.ResponseSchema):
    """StopUEcVHost - 停止UEC虚拟机"""

    fields = {}


"""
API: UnBindUEcFirewall

解绑防火墙
"""


class UnBindUEcFirewallRequestSchema(schema.RequestSchema):
    """UnBindUEcFirewall - 解绑防火墙"""

    fields = {
        "FirewallId": fields.Str(required=True, dump_to="FirewallId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
    }


class UnBindUEcFirewallResponseSchema(schema.ResponseSchema):
    """UnBindUEcFirewall - 解绑防火墙"""

    fields = {}


"""
API: UpdateUEcFirewall

更新防火墙信息，新增和删除规则
"""


class UpdateUEcFirewallParamRuleSchema(schema.RequestSchema):
    """UpdateUEcFirewallParamRule -"""

    fields = {
        "Action": fields.Str(required=True, dump_to="Action"),
        "Port": fields.Str(required=True, dump_to="Port"),
        "Priority": fields.Str(required=True, dump_to="Priority"),
        "ProtocolType": fields.Str(required=True, dump_to="ProtocolType"),
        "Remark": fields.Str(required=True, dump_to="Remark"),
        "SrcIp": fields.Str(required=True, dump_to="SrcIp"),
    }


class UpdateUEcFirewallRequestSchema(schema.RequestSchema):
    """UpdateUEcFirewall - 更新防火墙信息，新增和删除规则"""

    fields = {
        "FirewallId": fields.Str(required=True, dump_to="FirewallId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Rule": fields.List(UpdateUEcFirewallParamRuleSchema()),
    }


class UpdateUEcFirewallResponseSchema(schema.ResponseSchema):
    """UpdateUEcFirewall - 更新防火墙信息，新增和删除规则"""

    fields = {}


"""
API: UpdateUEcFirewallAttribute

更新防火墙名称及描述
"""


class UpdateUEcFirewallAttributeRequestSchema(schema.RequestSchema):
    """UpdateUEcFirewallAttribute - 更新防火墙名称及描述"""

    fields = {
        "FirewallId": fields.Str(required=True, dump_to="FirewallId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
    }


class UpdateUEcFirewallAttributeResponseSchema(schema.ResponseSchema):
    """UpdateUEcFirewallAttribute - 更新防火墙名称及描述"""

    fields = {}


"""
API: UpdateUEcSubnet

更新子网信息
"""


class UpdateUEcSubnetRequestSchema(schema.RequestSchema):
    """UpdateUEcSubnet - 更新子网信息"""

    fields = {
        "Comment": fields.Str(required=False, dump_to="Comment"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "SubnetName": fields.Str(required=False, dump_to="SubnetName"),
    }


class UpdateUEcSubnetResponseSchema(schema.ResponseSchema):
    """UpdateUEcSubnet - 更新子网信息"""

    fields = {}



import codecs

# Null bytes; no need to recreate these on each call to guess_json_utf
_null = "\x00".encode("ascii")  # encoding to ASCII for Python 3
_null2 = _null * 2
_null3 = _null * 3


def guess_json_utf(data):
    """guess_json_utf will detect the encoding of bytes,
    see `requests.utils.guess_json_utf`

    :rtype: str
    """
    # JSON always starts with two ASCII characters, so detection is as
    # easy as counting the nulls and from their location and count
    # determine the encoding. Also detect a BOM, if present.
    sample = data[:4]
    if sample in (codecs.BOM_UTF32_LE, codecs.BOM_UTF32_BE):
        return "utf-32"  # BOM included
    if sample[:3] == codecs.BOM_UTF8:
        return "utf-8-sig"  # BOM included, MS style (discouraged)
    if sample[:2] in (codecs.BOM_UTF16_LE, codecs.BOM_UTF16_BE):
        return "utf-16"  # BOM included
    nullcount = sample.count(_null)
    if nullcount == 0:
        return "utf-8"
    if nullcount == 2:
        if sample[::2] == _null2:  # 1st and 3rd are null
            return "utf-16-be"
        if sample[1::2] == _null2:  # 2nd and 4th are null
            return "utf-16-le"
        # Did not detect 2 valid UTF-16 ascii-range characters
    if nullcount == 3:
        if sample[:3] == _null3:
            return "utf-32-be"
        if sample[1:] == _null3:
            return "utf-32-le"
        # Did not detect a valid UTF-32 ascii-range character
    return None
